"""
Python module generated from Java source file org.bukkit.Sound

Java source file obtained from artifact spigot-api version 1.21.4-R0.1-20250303.102353-42

Because this Python module is automatically generated, it may contain errors
and/or code that cannot be parsed. Please report these issues at
https://github.com/magicmq/docs-translator/issues
"""
from com.google.common.base import Preconditions
from com.google.common.collect import Lists
from java.util import Locale
from org.bukkit import *
from org.bukkit.packs import DataPack
from org.bukkit.registry import RegistryAware
from org.bukkit.util import OldEnum
from typing import Any, Callable, Iterable, Tuple


class Sound(OldEnum, Keyed, RegistryAware):
    """
    An interface of Sounds the server is able to send to players.
    
    The sounds listed in this interface are present in the default server
    or can be enabled via a FeatureFlag.
    There may be additional sounds present in the server, for example from a DataPack
    which can be accessed via Registry.SOUNDS.
    
    **WARNING:** At any time, sounds may be added/removed from this interface or even
    Minecraft itself! There is no guarantee the sounds will play. There is no
    guarantee values will not be removed from this interface. As such, you should not
    depend on the ordinal values of this class.
    """

    AMBIENT_BASALT_DELTAS_ADDITIONS = getSound("ambient.basalt_deltas.additions")
    AMBIENT_BASALT_DELTAS_LOOP = getSound("ambient.basalt_deltas.loop")
    AMBIENT_BASALT_DELTAS_MOOD = getSound("ambient.basalt_deltas.mood")
    AMBIENT_CAVE = getSound("ambient.cave")
    AMBIENT_CRIMSON_FOREST_ADDITIONS = getSound("ambient.crimson_forest.additions")
    AMBIENT_CRIMSON_FOREST_LOOP = getSound("ambient.crimson_forest.loop")
    AMBIENT_CRIMSON_FOREST_MOOD = getSound("ambient.crimson_forest.mood")
    AMBIENT_NETHER_WASTES_ADDITIONS = getSound("ambient.nether_wastes.additions")
    AMBIENT_NETHER_WASTES_LOOP = getSound("ambient.nether_wastes.loop")
    AMBIENT_NETHER_WASTES_MOOD = getSound("ambient.nether_wastes.mood")
    AMBIENT_SOUL_SAND_VALLEY_ADDITIONS = getSound("ambient.soul_sand_valley.additions")
    AMBIENT_SOUL_SAND_VALLEY_LOOP = getSound("ambient.soul_sand_valley.loop")
    AMBIENT_SOUL_SAND_VALLEY_MOOD = getSound("ambient.soul_sand_valley.mood")
    AMBIENT_UNDERWATER_ENTER = getSound("ambient.underwater.enter")
    AMBIENT_UNDERWATER_EXIT = getSound("ambient.underwater.exit")
    AMBIENT_UNDERWATER_LOOP = getSound("ambient.underwater.loop")
    AMBIENT_UNDERWATER_LOOP_ADDITIONS = getSound("ambient.underwater.loop.additions")
    AMBIENT_UNDERWATER_LOOP_ADDITIONS_RARE = getSound("ambient.underwater.loop.additions.rare")
    AMBIENT_UNDERWATER_LOOP_ADDITIONS_ULTRA_RARE = getSound("ambient.underwater.loop.additions.ultra_rare")
    AMBIENT_WARPED_FOREST_ADDITIONS = getSound("ambient.warped_forest.additions")
    AMBIENT_WARPED_FOREST_LOOP = getSound("ambient.warped_forest.loop")
    AMBIENT_WARPED_FOREST_MOOD = getSound("ambient.warped_forest.mood")
    BLOCK_AMETHYST_BLOCK_BREAK = getSound("block.amethyst_block.break")
    BLOCK_AMETHYST_BLOCK_CHIME = getSound("block.amethyst_block.chime")
    BLOCK_AMETHYST_BLOCK_FALL = getSound("block.amethyst_block.fall")
    BLOCK_AMETHYST_BLOCK_HIT = getSound("block.amethyst_block.hit")
    BLOCK_AMETHYST_BLOCK_PLACE = getSound("block.amethyst_block.place")
    BLOCK_AMETHYST_BLOCK_RESONATE = getSound("block.amethyst_block.resonate")
    BLOCK_AMETHYST_BLOCK_STEP = getSound("block.amethyst_block.step")
    BLOCK_AMETHYST_CLUSTER_BREAK = getSound("block.amethyst_cluster.break")
    BLOCK_AMETHYST_CLUSTER_FALL = getSound("block.amethyst_cluster.fall")
    BLOCK_AMETHYST_CLUSTER_HIT = getSound("block.amethyst_cluster.hit")
    BLOCK_AMETHYST_CLUSTER_PLACE = getSound("block.amethyst_cluster.place")
    BLOCK_AMETHYST_CLUSTER_STEP = getSound("block.amethyst_cluster.step")
    BLOCK_ANCIENT_DEBRIS_BREAK = getSound("block.ancient_debris.break")
    BLOCK_ANCIENT_DEBRIS_FALL = getSound("block.ancient_debris.fall")
    BLOCK_ANCIENT_DEBRIS_HIT = getSound("block.ancient_debris.hit")
    BLOCK_ANCIENT_DEBRIS_PLACE = getSound("block.ancient_debris.place")
    BLOCK_ANCIENT_DEBRIS_STEP = getSound("block.ancient_debris.step")
    BLOCK_ANVIL_BREAK = getSound("block.anvil.break")
    BLOCK_ANVIL_DESTROY = getSound("block.anvil.destroy")
    BLOCK_ANVIL_FALL = getSound("block.anvil.fall")
    BLOCK_ANVIL_HIT = getSound("block.anvil.hit")
    BLOCK_ANVIL_LAND = getSound("block.anvil.land")
    BLOCK_ANVIL_PLACE = getSound("block.anvil.place")
    BLOCK_ANVIL_STEP = getSound("block.anvil.step")
    BLOCK_ANVIL_USE = getSound("block.anvil.use")
    BLOCK_AZALEA_BREAK = getSound("block.azalea.break")
    BLOCK_AZALEA_FALL = getSound("block.azalea.fall")
    BLOCK_AZALEA_HIT = getSound("block.azalea.hit")
    BLOCK_AZALEA_LEAVES_BREAK = getSound("block.azalea_leaves.break")
    BLOCK_AZALEA_LEAVES_FALL = getSound("block.azalea_leaves.fall")
    BLOCK_AZALEA_LEAVES_HIT = getSound("block.azalea_leaves.hit")
    BLOCK_AZALEA_LEAVES_PLACE = getSound("block.azalea_leaves.place")
    BLOCK_AZALEA_LEAVES_STEP = getSound("block.azalea_leaves.step")
    BLOCK_AZALEA_PLACE = getSound("block.azalea.place")
    BLOCK_AZALEA_STEP = getSound("block.azalea.step")
    BLOCK_BAMBOO_BREAK = getSound("block.bamboo.break")
    BLOCK_BAMBOO_FALL = getSound("block.bamboo.fall")
    BLOCK_BAMBOO_HIT = getSound("block.bamboo.hit")
    BLOCK_BAMBOO_PLACE = getSound("block.bamboo.place")
    BLOCK_BAMBOO_SAPLING_BREAK = getSound("block.bamboo_sapling.break")
    BLOCK_BAMBOO_SAPLING_HIT = getSound("block.bamboo_sapling.hit")
    BLOCK_BAMBOO_SAPLING_PLACE = getSound("block.bamboo_sapling.place")
    BLOCK_BAMBOO_STEP = getSound("block.bamboo.step")
    BLOCK_BAMBOO_WOOD_BREAK = getSound("block.bamboo_wood.break")
    BLOCK_BAMBOO_WOOD_BUTTON_CLICK_OFF = getSound("block.bamboo_wood_button.click_off")
    BLOCK_BAMBOO_WOOD_BUTTON_CLICK_ON = getSound("block.bamboo_wood_button.click_on")
    BLOCK_BAMBOO_WOOD_DOOR_CLOSE = getSound("block.bamboo_wood_door.close")
    BLOCK_BAMBOO_WOOD_DOOR_OPEN = getSound("block.bamboo_wood_door.open")
    BLOCK_BAMBOO_WOOD_FALL = getSound("block.bamboo_wood.fall")
    BLOCK_BAMBOO_WOOD_FENCE_GATE_CLOSE = getSound("block.bamboo_wood_fence_gate.close")
    BLOCK_BAMBOO_WOOD_FENCE_GATE_OPEN = getSound("block.bamboo_wood_fence_gate.open")
    BLOCK_BAMBOO_WOOD_HANGING_SIGN_BREAK = getSound("block.bamboo_wood_hanging_sign.break")
    BLOCK_BAMBOO_WOOD_HANGING_SIGN_FALL = getSound("block.bamboo_wood_hanging_sign.fall")
    BLOCK_BAMBOO_WOOD_HANGING_SIGN_HIT = getSound("block.bamboo_wood_hanging_sign.hit")
    BLOCK_BAMBOO_WOOD_HANGING_SIGN_PLACE = getSound("block.bamboo_wood_hanging_sign.place")
    BLOCK_BAMBOO_WOOD_HANGING_SIGN_STEP = getSound("block.bamboo_wood_hanging_sign.step")
    BLOCK_BAMBOO_WOOD_HIT = getSound("block.bamboo_wood.hit")
    BLOCK_BAMBOO_WOOD_PLACE = getSound("block.bamboo_wood.place")
    BLOCK_BAMBOO_WOOD_PRESSURE_PLATE_CLICK_OFF = getSound("block.bamboo_wood_pressure_plate.click_off")
    BLOCK_BAMBOO_WOOD_PRESSURE_PLATE_CLICK_ON = getSound("block.bamboo_wood_pressure_plate.click_on")
    BLOCK_BAMBOO_WOOD_STEP = getSound("block.bamboo_wood.step")
    BLOCK_BAMBOO_WOOD_TRAPDOOR_CLOSE = getSound("block.bamboo_wood_trapdoor.close")
    BLOCK_BAMBOO_WOOD_TRAPDOOR_OPEN = getSound("block.bamboo_wood_trapdoor.open")
    BLOCK_BARREL_CLOSE = getSound("block.barrel.close")
    BLOCK_BARREL_OPEN = getSound("block.barrel.open")
    BLOCK_BASALT_BREAK = getSound("block.basalt.break")
    BLOCK_BASALT_FALL = getSound("block.basalt.fall")
    BLOCK_BASALT_HIT = getSound("block.basalt.hit")
    BLOCK_BASALT_PLACE = getSound("block.basalt.place")
    BLOCK_BASALT_STEP = getSound("block.basalt.step")
    BLOCK_BEACON_ACTIVATE = getSound("block.beacon.activate")
    BLOCK_BEACON_AMBIENT = getSound("block.beacon.ambient")
    BLOCK_BEACON_DEACTIVATE = getSound("block.beacon.deactivate")
    BLOCK_BEACON_POWER_SELECT = getSound("block.beacon.power_select")
    BLOCK_BEEHIVE_DRIP = getSound("block.beehive.drip")
    BLOCK_BEEHIVE_ENTER = getSound("block.beehive.enter")
    BLOCK_BEEHIVE_EXIT = getSound("block.beehive.exit")
    BLOCK_BEEHIVE_SHEAR = getSound("block.beehive.shear")
    BLOCK_BEEHIVE_WORK = getSound("block.beehive.work")
    BLOCK_BELL_RESONATE = getSound("block.bell.resonate")
    BLOCK_BELL_USE = getSound("block.bell.use")
    BLOCK_BIG_DRIPLEAF_BREAK = getSound("block.big_dripleaf.break")
    BLOCK_BIG_DRIPLEAF_FALL = getSound("block.big_dripleaf.fall")
    BLOCK_BIG_DRIPLEAF_HIT = getSound("block.big_dripleaf.hit")
    BLOCK_BIG_DRIPLEAF_PLACE = getSound("block.big_dripleaf.place")
    BLOCK_BIG_DRIPLEAF_STEP = getSound("block.big_dripleaf.step")
    BLOCK_BIG_DRIPLEAF_TILT_DOWN = getSound("block.big_dripleaf.tilt_down")
    BLOCK_BIG_DRIPLEAF_TILT_UP = getSound("block.big_dripleaf.tilt_up")
    BLOCK_BLASTFURNACE_FIRE_CRACKLE = getSound("block.blastfurnace.fire_crackle")
    BLOCK_BONE_BLOCK_BREAK = getSound("block.bone_block.break")
    BLOCK_BONE_BLOCK_FALL = getSound("block.bone_block.fall")
    BLOCK_BONE_BLOCK_HIT = getSound("block.bone_block.hit")
    BLOCK_BONE_BLOCK_PLACE = getSound("block.bone_block.place")
    BLOCK_BONE_BLOCK_STEP = getSound("block.bone_block.step")
    BLOCK_BREWING_STAND_BREW = getSound("block.brewing_stand.brew")
    BLOCK_BUBBLE_COLUMN_BUBBLE_POP = getSound("block.bubble_column.bubble_pop")
    BLOCK_BUBBLE_COLUMN_UPWARDS_AMBIENT = getSound("block.bubble_column.upwards_ambient")
    BLOCK_BUBBLE_COLUMN_UPWARDS_INSIDE = getSound("block.bubble_column.upwards_inside")
    BLOCK_BUBBLE_COLUMN_WHIRLPOOL_AMBIENT = getSound("block.bubble_column.whirlpool_ambient")
    BLOCK_BUBBLE_COLUMN_WHIRLPOOL_INSIDE = getSound("block.bubble_column.whirlpool_inside")
    BLOCK_CAKE_ADD_CANDLE = getSound("block.cake.add_candle")
    BLOCK_CALCITE_BREAK = getSound("block.calcite.break")
    BLOCK_CALCITE_FALL = getSound("block.calcite.fall")
    BLOCK_CALCITE_HIT = getSound("block.calcite.hit")
    BLOCK_CALCITE_PLACE = getSound("block.calcite.place")
    BLOCK_CALCITE_STEP = getSound("block.calcite.step")
    BLOCK_CAMPFIRE_CRACKLE = getSound("block.campfire.crackle")
    BLOCK_CANDLE_AMBIENT = getSound("block.candle.ambient")
    BLOCK_CANDLE_BREAK = getSound("block.candle.break")
    BLOCK_CANDLE_EXTINGUISH = getSound("block.candle.extinguish")
    BLOCK_CANDLE_FALL = getSound("block.candle.fall")
    BLOCK_CANDLE_HIT = getSound("block.candle.hit")
    BLOCK_CANDLE_PLACE = getSound("block.candle.place")
    BLOCK_CANDLE_STEP = getSound("block.candle.step")
    BLOCK_CAVE_VINES_BREAK = getSound("block.cave_vines.break")
    BLOCK_CAVE_VINES_FALL = getSound("block.cave_vines.fall")
    BLOCK_CAVE_VINES_HIT = getSound("block.cave_vines.hit")
    BLOCK_CAVE_VINES_PICK_BERRIES = getSound("block.cave_vines.pick_berries")
    BLOCK_CAVE_VINES_PLACE = getSound("block.cave_vines.place")
    BLOCK_CAVE_VINES_STEP = getSound("block.cave_vines.step")
    BLOCK_CHAIN_BREAK = getSound("block.chain.break")
    BLOCK_CHAIN_FALL = getSound("block.chain.fall")
    BLOCK_CHAIN_HIT = getSound("block.chain.hit")
    BLOCK_CHAIN_PLACE = getSound("block.chain.place")
    BLOCK_CHAIN_STEP = getSound("block.chain.step")
    BLOCK_CHERRY_LEAVES_BREAK = getSound("block.cherry_leaves.break")
    BLOCK_CHERRY_LEAVES_FALL = getSound("block.cherry_leaves.fall")
    BLOCK_CHERRY_LEAVES_HIT = getSound("block.cherry_leaves.hit")
    BLOCK_CHERRY_LEAVES_PLACE = getSound("block.cherry_leaves.place")
    BLOCK_CHERRY_LEAVES_STEP = getSound("block.cherry_leaves.step")
    BLOCK_CHERRY_SAPLING_BREAK = getSound("block.cherry_sapling.break")
    BLOCK_CHERRY_SAPLING_FALL = getSound("block.cherry_sapling.fall")
    BLOCK_CHERRY_SAPLING_HIT = getSound("block.cherry_sapling.hit")
    BLOCK_CHERRY_SAPLING_PLACE = getSound("block.cherry_sapling.place")
    BLOCK_CHERRY_SAPLING_STEP = getSound("block.cherry_sapling.step")
    BLOCK_CHERRY_WOOD_BREAK = getSound("block.cherry_wood.break")
    BLOCK_CHERRY_WOOD_BUTTON_CLICK_OFF = getSound("block.cherry_wood_button.click_off")
    BLOCK_CHERRY_WOOD_BUTTON_CLICK_ON = getSound("block.cherry_wood_button.click_on")
    BLOCK_CHERRY_WOOD_DOOR_CLOSE = getSound("block.cherry_wood_door.close")
    BLOCK_CHERRY_WOOD_DOOR_OPEN = getSound("block.cherry_wood_door.open")
    BLOCK_CHERRY_WOOD_FALL = getSound("block.cherry_wood.fall")
    BLOCK_CHERRY_WOOD_FENCE_GATE_CLOSE = getSound("block.cherry_wood_fence_gate.close")
    BLOCK_CHERRY_WOOD_FENCE_GATE_OPEN = getSound("block.cherry_wood_fence_gate.open")
    BLOCK_CHERRY_WOOD_HANGING_SIGN_BREAK = getSound("block.cherry_wood_hanging_sign.break")
    BLOCK_CHERRY_WOOD_HANGING_SIGN_FALL = getSound("block.cherry_wood_hanging_sign.fall")
    BLOCK_CHERRY_WOOD_HANGING_SIGN_HIT = getSound("block.cherry_wood_hanging_sign.hit")
    BLOCK_CHERRY_WOOD_HANGING_SIGN_PLACE = getSound("block.cherry_wood_hanging_sign.place")
    BLOCK_CHERRY_WOOD_HANGING_SIGN_STEP = getSound("block.cherry_wood_hanging_sign.step")
    BLOCK_CHERRY_WOOD_HIT = getSound("block.cherry_wood.hit")
    BLOCK_CHERRY_WOOD_PLACE = getSound("block.cherry_wood.place")
    BLOCK_CHERRY_WOOD_PRESSURE_PLATE_CLICK_OFF = getSound("block.cherry_wood_pressure_plate.click_off")
    BLOCK_CHERRY_WOOD_PRESSURE_PLATE_CLICK_ON = getSound("block.cherry_wood_pressure_plate.click_on")
    BLOCK_CHERRY_WOOD_STEP = getSound("block.cherry_wood.step")
    BLOCK_CHERRY_WOOD_TRAPDOOR_CLOSE = getSound("block.cherry_wood_trapdoor.close")
    BLOCK_CHERRY_WOOD_TRAPDOOR_OPEN = getSound("block.cherry_wood_trapdoor.open")
    BLOCK_CHEST_CLOSE = getSound("block.chest.close")
    BLOCK_CHEST_LOCKED = getSound("block.chest.locked")
    BLOCK_CHEST_OPEN = getSound("block.chest.open")
    BLOCK_CHISELED_BOOKSHELF_BREAK = getSound("block.chiseled_bookshelf.break")
    BLOCK_CHISELED_BOOKSHELF_FALL = getSound("block.chiseled_bookshelf.fall")
    BLOCK_CHISELED_BOOKSHELF_HIT = getSound("block.chiseled_bookshelf.hit")
    BLOCK_CHISELED_BOOKSHELF_INSERT = getSound("block.chiseled_bookshelf.insert")
    BLOCK_CHISELED_BOOKSHELF_INSERT_ENCHANTED = getSound("block.chiseled_bookshelf.insert.enchanted")
    BLOCK_CHISELED_BOOKSHELF_PICKUP = getSound("block.chiseled_bookshelf.pickup")
    BLOCK_CHISELED_BOOKSHELF_PICKUP_ENCHANTED = getSound("block.chiseled_bookshelf.pickup.enchanted")
    BLOCK_CHISELED_BOOKSHELF_PLACE = getSound("block.chiseled_bookshelf.place")
    BLOCK_CHISELED_BOOKSHELF_STEP = getSound("block.chiseled_bookshelf.step")
    BLOCK_CHORUS_FLOWER_DEATH = getSound("block.chorus_flower.death")
    BLOCK_CHORUS_FLOWER_GROW = getSound("block.chorus_flower.grow")
    BLOCK_COBWEB_BREAK = getSound("block.cobweb.break")
    BLOCK_COBWEB_FALL = getSound("block.cobweb.fall")
    BLOCK_COBWEB_HIT = getSound("block.cobweb.hit")
    BLOCK_COBWEB_PLACE = getSound("block.cobweb.place")
    BLOCK_COBWEB_STEP = getSound("block.cobweb.step")
    BLOCK_COMPARATOR_CLICK = getSound("block.comparator.click")
    BLOCK_COMPOSTER_EMPTY = getSound("block.composter.empty")
    BLOCK_COMPOSTER_FILL = getSound("block.composter.fill")
    BLOCK_COMPOSTER_FILL_SUCCESS = getSound("block.composter.fill_success")
    BLOCK_COMPOSTER_READY = getSound("block.composter.ready")
    BLOCK_CONDUIT_ACTIVATE = getSound("block.conduit.activate")
    BLOCK_CONDUIT_AMBIENT = getSound("block.conduit.ambient")
    BLOCK_CONDUIT_AMBIENT_SHORT = getSound("block.conduit.ambient.short")
    BLOCK_CONDUIT_ATTACK_TARGET = getSound("block.conduit.attack.target")
    BLOCK_CONDUIT_DEACTIVATE = getSound("block.conduit.deactivate")
    BLOCK_COPPER_BREAK = getSound("block.copper.break")
    BLOCK_COPPER_BULB_BREAK = getSound("block.copper_bulb.break")
    BLOCK_COPPER_BULB_FALL = getSound("block.copper_bulb.fall")
    BLOCK_COPPER_BULB_HIT = getSound("block.copper_bulb.hit")
    BLOCK_COPPER_BULB_PLACE = getSound("block.copper_bulb.place")
    BLOCK_COPPER_BULB_STEP = getSound("block.copper_bulb.step")
    BLOCK_COPPER_BULB_TURN_OFF = getSound("block.copper_bulb.turn_off")
    BLOCK_COPPER_BULB_TURN_ON = getSound("block.copper_bulb.turn_on")
    BLOCK_COPPER_DOOR_CLOSE = getSound("block.copper_door.close")
    BLOCK_COPPER_DOOR_OPEN = getSound("block.copper_door.open")
    BLOCK_COPPER_FALL = getSound("block.copper.fall")
    BLOCK_COPPER_GRATE_BREAK = getSound("block.copper_grate.break")
    BLOCK_COPPER_GRATE_FALL = getSound("block.copper_grate.fall")
    BLOCK_COPPER_GRATE_HIT = getSound("block.copper_grate.hit")
    BLOCK_COPPER_GRATE_PLACE = getSound("block.copper_grate.place")
    BLOCK_COPPER_GRATE_STEP = getSound("block.copper_grate.step")
    BLOCK_COPPER_HIT = getSound("block.copper.hit")
    BLOCK_COPPER_PLACE = getSound("block.copper.place")
    BLOCK_COPPER_STEP = getSound("block.copper.step")
    BLOCK_COPPER_TRAPDOOR_CLOSE = getSound("block.copper_trapdoor.close")
    BLOCK_COPPER_TRAPDOOR_OPEN = getSound("block.copper_trapdoor.open")
    BLOCK_CORAL_BLOCK_BREAK = getSound("block.coral_block.break")
    BLOCK_CORAL_BLOCK_FALL = getSound("block.coral_block.fall")
    BLOCK_CORAL_BLOCK_HIT = getSound("block.coral_block.hit")
    BLOCK_CORAL_BLOCK_PLACE = getSound("block.coral_block.place")
    BLOCK_CORAL_BLOCK_STEP = getSound("block.coral_block.step")
    BLOCK_CRAFTER_CRAFT = getSound("block.crafter.craft")
    BLOCK_CRAFTER_FAIL = getSound("block.crafter.fail")
    BLOCK_CREAKING_HEART_BREAK = getSound("block.creaking_heart.break")
    BLOCK_CREAKING_HEART_FALL = getSound("block.creaking_heart.fall")
    BLOCK_CREAKING_HEART_HIT = getSound("block.creaking_heart.hit")
    BLOCK_CREAKING_HEART_HURT = getSound("block.creaking_heart.hurt")
    BLOCK_CREAKING_HEART_IDLE = getSound("block.creaking_heart.idle")
    BLOCK_CREAKING_HEART_PLACE = getSound("block.creaking_heart.place")
    BLOCK_CREAKING_HEART_SPAWN = getSound("block.creaking_heart.spawn")
    BLOCK_CREAKING_HEART_STEP = getSound("block.creaking_heart.step")
    BLOCK_CROP_BREAK = getSound("block.crop.break")
    BLOCK_DECORATED_POT_BREAK = getSound("block.decorated_pot.break")
    BLOCK_DECORATED_POT_FALL = getSound("block.decorated_pot.fall")
    BLOCK_DECORATED_POT_HIT = getSound("block.decorated_pot.hit")
    BLOCK_DECORATED_POT_INSERT = getSound("block.decorated_pot.insert")
    BLOCK_DECORATED_POT_INSERT_FAIL = getSound("block.decorated_pot.insert_fail")
    BLOCK_DECORATED_POT_PLACE = getSound("block.decorated_pot.place")
    BLOCK_DECORATED_POT_SHATTER = getSound("block.decorated_pot.shatter")
    BLOCK_DECORATED_POT_STEP = getSound("block.decorated_pot.step")
    BLOCK_DEEPSLATE_BREAK = getSound("block.deepslate.break")
    BLOCK_DEEPSLATE_BRICKS_BREAK = getSound("block.deepslate_bricks.break")
    BLOCK_DEEPSLATE_BRICKS_FALL = getSound("block.deepslate_bricks.fall")
    BLOCK_DEEPSLATE_BRICKS_HIT = getSound("block.deepslate_bricks.hit")
    BLOCK_DEEPSLATE_BRICKS_PLACE = getSound("block.deepslate_bricks.place")
    BLOCK_DEEPSLATE_BRICKS_STEP = getSound("block.deepslate_bricks.step")
    BLOCK_DEEPSLATE_FALL = getSound("block.deepslate.fall")
    BLOCK_DEEPSLATE_HIT = getSound("block.deepslate.hit")
    BLOCK_DEEPSLATE_PLACE = getSound("block.deepslate.place")
    BLOCK_DEEPSLATE_STEP = getSound("block.deepslate.step")
    BLOCK_DEEPSLATE_TILES_BREAK = getSound("block.deepslate_tiles.break")
    BLOCK_DEEPSLATE_TILES_FALL = getSound("block.deepslate_tiles.fall")
    BLOCK_DEEPSLATE_TILES_HIT = getSound("block.deepslate_tiles.hit")
    BLOCK_DEEPSLATE_TILES_PLACE = getSound("block.deepslate_tiles.place")
    BLOCK_DEEPSLATE_TILES_STEP = getSound("block.deepslate_tiles.step")
    BLOCK_DISPENSER_DISPENSE = getSound("block.dispenser.dispense")
    BLOCK_DISPENSER_FAIL = getSound("block.dispenser.fail")
    BLOCK_DISPENSER_LAUNCH = getSound("block.dispenser.launch")
    BLOCK_DRIPSTONE_BLOCK_BREAK = getSound("block.dripstone_block.break")
    BLOCK_DRIPSTONE_BLOCK_FALL = getSound("block.dripstone_block.fall")
    BLOCK_DRIPSTONE_BLOCK_HIT = getSound("block.dripstone_block.hit")
    BLOCK_DRIPSTONE_BLOCK_PLACE = getSound("block.dripstone_block.place")
    BLOCK_DRIPSTONE_BLOCK_STEP = getSound("block.dripstone_block.step")
    BLOCK_ENCHANTMENT_TABLE_USE = getSound("block.enchantment_table.use")
    BLOCK_ENDER_CHEST_CLOSE = getSound("block.ender_chest.close")
    BLOCK_ENDER_CHEST_OPEN = getSound("block.ender_chest.open")
    BLOCK_END_GATEWAY_SPAWN = getSound("block.end_gateway.spawn")
    BLOCK_END_PORTAL_FRAME_FILL = getSound("block.end_portal_frame.fill")
    BLOCK_END_PORTAL_SPAWN = getSound("block.end_portal.spawn")
    BLOCK_EYEBLOSSOM_CLOSE = getSound("block.eyeblossom.close")
    BLOCK_EYEBLOSSOM_CLOSE_LONG = getSound("block.eyeblossom.close_long")
    BLOCK_EYEBLOSSOM_IDLE = getSound("block.eyeblossom.idle")
    BLOCK_EYEBLOSSOM_OPEN = getSound("block.eyeblossom.open")
    BLOCK_EYEBLOSSOM_OPEN_LONG = getSound("block.eyeblossom.open_long")
    BLOCK_FENCE_GATE_CLOSE = getSound("block.fence_gate.close")
    BLOCK_FENCE_GATE_OPEN = getSound("block.fence_gate.open")
    BLOCK_FIRE_AMBIENT = getSound("block.fire.ambient")
    BLOCK_FIRE_EXTINGUISH = getSound("block.fire.extinguish")
    BLOCK_FLOWERING_AZALEA_BREAK = getSound("block.flowering_azalea.break")
    BLOCK_FLOWERING_AZALEA_FALL = getSound("block.flowering_azalea.fall")
    BLOCK_FLOWERING_AZALEA_HIT = getSound("block.flowering_azalea.hit")
    BLOCK_FLOWERING_AZALEA_PLACE = getSound("block.flowering_azalea.place")
    BLOCK_FLOWERING_AZALEA_STEP = getSound("block.flowering_azalea.step")
    BLOCK_FROGLIGHT_BREAK = getSound("block.froglight.break")
    BLOCK_FROGLIGHT_FALL = getSound("block.froglight.fall")
    BLOCK_FROGLIGHT_HIT = getSound("block.froglight.hit")
    BLOCK_FROGLIGHT_PLACE = getSound("block.froglight.place")
    BLOCK_FROGLIGHT_STEP = getSound("block.froglight.step")
    BLOCK_FROGSPAWN_BREAK = getSound("block.frogspawn.break")
    BLOCK_FROGSPAWN_FALL = getSound("block.frogspawn.fall")
    BLOCK_FROGSPAWN_HATCH = getSound("block.frogspawn.hatch")
    BLOCK_FROGSPAWN_HIT = getSound("block.frogspawn.hit")
    BLOCK_FROGSPAWN_PLACE = getSound("block.frogspawn.place")
    BLOCK_FROGSPAWN_STEP = getSound("block.frogspawn.step")
    BLOCK_FUNGUS_BREAK = getSound("block.fungus.break")
    BLOCK_FUNGUS_FALL = getSound("block.fungus.fall")
    BLOCK_FUNGUS_HIT = getSound("block.fungus.hit")
    BLOCK_FUNGUS_PLACE = getSound("block.fungus.place")
    BLOCK_FUNGUS_STEP = getSound("block.fungus.step")
    BLOCK_FURNACE_FIRE_CRACKLE = getSound("block.furnace.fire_crackle")
    BLOCK_GILDED_BLACKSTONE_BREAK = getSound("block.gilded_blackstone.break")
    BLOCK_GILDED_BLACKSTONE_FALL = getSound("block.gilded_blackstone.fall")
    BLOCK_GILDED_BLACKSTONE_HIT = getSound("block.gilded_blackstone.hit")
    BLOCK_GILDED_BLACKSTONE_PLACE = getSound("block.gilded_blackstone.place")
    BLOCK_GILDED_BLACKSTONE_STEP = getSound("block.gilded_blackstone.step")
    BLOCK_GLASS_BREAK = getSound("block.glass.break")
    BLOCK_GLASS_FALL = getSound("block.glass.fall")
    BLOCK_GLASS_HIT = getSound("block.glass.hit")
    BLOCK_GLASS_PLACE = getSound("block.glass.place")
    BLOCK_GLASS_STEP = getSound("block.glass.step")
    BLOCK_GRASS_BREAK = getSound("block.grass.break")
    BLOCK_GRASS_FALL = getSound("block.grass.fall")
    BLOCK_GRASS_HIT = getSound("block.grass.hit")
    BLOCK_GRASS_PLACE = getSound("block.grass.place")
    BLOCK_GRASS_STEP = getSound("block.grass.step")
    BLOCK_GRAVEL_BREAK = getSound("block.gravel.break")
    BLOCK_GRAVEL_FALL = getSound("block.gravel.fall")
    BLOCK_GRAVEL_HIT = getSound("block.gravel.hit")
    BLOCK_GRAVEL_PLACE = getSound("block.gravel.place")
    BLOCK_GRAVEL_STEP = getSound("block.gravel.step")
    BLOCK_GRINDSTONE_USE = getSound("block.grindstone.use")
    BLOCK_GROWING_PLANT_CROP = getSound("block.growing_plant.crop")
    BLOCK_HANGING_ROOTS_BREAK = getSound("block.hanging_roots.break")
    BLOCK_HANGING_ROOTS_FALL = getSound("block.hanging_roots.fall")
    BLOCK_HANGING_ROOTS_HIT = getSound("block.hanging_roots.hit")
    BLOCK_HANGING_ROOTS_PLACE = getSound("block.hanging_roots.place")
    BLOCK_HANGING_ROOTS_STEP = getSound("block.hanging_roots.step")
    BLOCK_HANGING_SIGN_BREAK = getSound("block.hanging_sign.break")
    BLOCK_HANGING_SIGN_FALL = getSound("block.hanging_sign.fall")
    BLOCK_HANGING_SIGN_HIT = getSound("block.hanging_sign.hit")
    BLOCK_HANGING_SIGN_PLACE = getSound("block.hanging_sign.place")
    BLOCK_HANGING_SIGN_STEP = getSound("block.hanging_sign.step")
    BLOCK_HANGING_SIGN_WAXED_INTERACT_FAIL = getSound("block.hanging_sign.waxed_interact_fail")
    BLOCK_HEAVY_CORE_BREAK = getSound("block.heavy_core.break")
    BLOCK_HEAVY_CORE_FALL = getSound("block.heavy_core.fall")
    BLOCK_HEAVY_CORE_HIT = getSound("block.heavy_core.hit")
    BLOCK_HEAVY_CORE_PLACE = getSound("block.heavy_core.place")
    BLOCK_HEAVY_CORE_STEP = getSound("block.heavy_core.step")
    BLOCK_HONEY_BLOCK_BREAK = getSound("block.honey_block.break")
    BLOCK_HONEY_BLOCK_FALL = getSound("block.honey_block.fall")
    BLOCK_HONEY_BLOCK_HIT = getSound("block.honey_block.hit")
    BLOCK_HONEY_BLOCK_PLACE = getSound("block.honey_block.place")
    BLOCK_HONEY_BLOCK_SLIDE = getSound("block.honey_block.slide")
    BLOCK_HONEY_BLOCK_STEP = getSound("block.honey_block.step")
    BLOCK_IRON_DOOR_CLOSE = getSound("block.iron_door.close")
    BLOCK_IRON_DOOR_OPEN = getSound("block.iron_door.open")
    BLOCK_IRON_TRAPDOOR_CLOSE = getSound("block.iron_trapdoor.close")
    BLOCK_IRON_TRAPDOOR_OPEN = getSound("block.iron_trapdoor.open")
    BLOCK_LADDER_BREAK = getSound("block.ladder.break")
    BLOCK_LADDER_FALL = getSound("block.ladder.fall")
    BLOCK_LADDER_HIT = getSound("block.ladder.hit")
    BLOCK_LADDER_PLACE = getSound("block.ladder.place")
    BLOCK_LADDER_STEP = getSound("block.ladder.step")
    BLOCK_LANTERN_BREAK = getSound("block.lantern.break")
    BLOCK_LANTERN_FALL = getSound("block.lantern.fall")
    BLOCK_LANTERN_HIT = getSound("block.lantern.hit")
    BLOCK_LANTERN_PLACE = getSound("block.lantern.place")
    BLOCK_LANTERN_STEP = getSound("block.lantern.step")
    BLOCK_LARGE_AMETHYST_BUD_BREAK = getSound("block.large_amethyst_bud.break")
    BLOCK_LARGE_AMETHYST_BUD_PLACE = getSound("block.large_amethyst_bud.place")
    BLOCK_LAVA_AMBIENT = getSound("block.lava.ambient")
    BLOCK_LAVA_EXTINGUISH = getSound("block.lava.extinguish")
    BLOCK_LAVA_POP = getSound("block.lava.pop")
    BLOCK_LEVER_CLICK = getSound("block.lever.click")
    BLOCK_LILY_PAD_PLACE = getSound("block.lily_pad.place")
    BLOCK_LODESTONE_BREAK = getSound("block.lodestone.break")
    BLOCK_LODESTONE_FALL = getSound("block.lodestone.fall")
    BLOCK_LODESTONE_HIT = getSound("block.lodestone.hit")
    BLOCK_LODESTONE_PLACE = getSound("block.lodestone.place")
    BLOCK_LODESTONE_STEP = getSound("block.lodestone.step")
    BLOCK_MANGROVE_ROOTS_BREAK = getSound("block.mangrove_roots.break")
    BLOCK_MANGROVE_ROOTS_FALL = getSound("block.mangrove_roots.fall")
    BLOCK_MANGROVE_ROOTS_HIT = getSound("block.mangrove_roots.hit")
    BLOCK_MANGROVE_ROOTS_PLACE = getSound("block.mangrove_roots.place")
    BLOCK_MANGROVE_ROOTS_STEP = getSound("block.mangrove_roots.step")
    BLOCK_MEDIUM_AMETHYST_BUD_BREAK = getSound("block.medium_amethyst_bud.break")
    BLOCK_MEDIUM_AMETHYST_BUD_PLACE = getSound("block.medium_amethyst_bud.place")
    BLOCK_METAL_BREAK = getSound("block.metal.break")
    BLOCK_METAL_FALL = getSound("block.metal.fall")
    BLOCK_METAL_HIT = getSound("block.metal.hit")
    BLOCK_METAL_PLACE = getSound("block.metal.place")
    BLOCK_METAL_PRESSURE_PLATE_CLICK_OFF = getSound("block.metal_pressure_plate.click_off")
    BLOCK_METAL_PRESSURE_PLATE_CLICK_ON = getSound("block.metal_pressure_plate.click_on")
    BLOCK_METAL_STEP = getSound("block.metal.step")
    BLOCK_MOSS_BREAK = getSound("block.moss.break")
    BLOCK_MOSS_CARPET_BREAK = getSound("block.moss_carpet.break")
    BLOCK_MOSS_CARPET_FALL = getSound("block.moss_carpet.fall")
    BLOCK_MOSS_CARPET_HIT = getSound("block.moss_carpet.hit")
    BLOCK_MOSS_CARPET_PLACE = getSound("block.moss_carpet.place")
    BLOCK_MOSS_CARPET_STEP = getSound("block.moss_carpet.step")
    BLOCK_MOSS_FALL = getSound("block.moss.fall")
    BLOCK_MOSS_HIT = getSound("block.moss.hit")
    BLOCK_MOSS_PLACE = getSound("block.moss.place")
    BLOCK_MOSS_STEP = getSound("block.moss.step")
    BLOCK_MUDDY_MANGROVE_ROOTS_BREAK = getSound("block.muddy_mangrove_roots.break")
    BLOCK_MUDDY_MANGROVE_ROOTS_FALL = getSound("block.muddy_mangrove_roots.fall")
    BLOCK_MUDDY_MANGROVE_ROOTS_HIT = getSound("block.muddy_mangrove_roots.hit")
    BLOCK_MUDDY_MANGROVE_ROOTS_PLACE = getSound("block.muddy_mangrove_roots.place")
    BLOCK_MUDDY_MANGROVE_ROOTS_STEP = getSound("block.muddy_mangrove_roots.step")
    BLOCK_MUD_BREAK = getSound("block.mud.break")
    BLOCK_MUD_BRICKS_BREAK = getSound("block.mud_bricks.break")
    BLOCK_MUD_BRICKS_FALL = getSound("block.mud_bricks.fall")
    BLOCK_MUD_BRICKS_HIT = getSound("block.mud_bricks.hit")
    BLOCK_MUD_BRICKS_PLACE = getSound("block.mud_bricks.place")
    BLOCK_MUD_BRICKS_STEP = getSound("block.mud_bricks.step")
    BLOCK_MUD_FALL = getSound("block.mud.fall")
    BLOCK_MUD_HIT = getSound("block.mud.hit")
    BLOCK_MUD_PLACE = getSound("block.mud.place")
    BLOCK_MUD_STEP = getSound("block.mud.step")
    BLOCK_NETHERITE_BLOCK_BREAK = getSound("block.netherite_block.break")
    BLOCK_NETHERITE_BLOCK_FALL = getSound("block.netherite_block.fall")
    BLOCK_NETHERITE_BLOCK_HIT = getSound("block.netherite_block.hit")
    BLOCK_NETHERITE_BLOCK_PLACE = getSound("block.netherite_block.place")
    BLOCK_NETHERITE_BLOCK_STEP = getSound("block.netherite_block.step")
    BLOCK_NETHERRACK_BREAK = getSound("block.netherrack.break")
    BLOCK_NETHERRACK_FALL = getSound("block.netherrack.fall")
    BLOCK_NETHERRACK_HIT = getSound("block.netherrack.hit")
    BLOCK_NETHERRACK_PLACE = getSound("block.netherrack.place")
    BLOCK_NETHERRACK_STEP = getSound("block.netherrack.step")
    BLOCK_NETHER_BRICKS_BREAK = getSound("block.nether_bricks.break")
    BLOCK_NETHER_BRICKS_FALL = getSound("block.nether_bricks.fall")
    BLOCK_NETHER_BRICKS_HIT = getSound("block.nether_bricks.hit")
    BLOCK_NETHER_BRICKS_PLACE = getSound("block.nether_bricks.place")
    BLOCK_NETHER_BRICKS_STEP = getSound("block.nether_bricks.step")
    BLOCK_NETHER_GOLD_ORE_BREAK = getSound("block.nether_gold_ore.break")
    BLOCK_NETHER_GOLD_ORE_FALL = getSound("block.nether_gold_ore.fall")
    BLOCK_NETHER_GOLD_ORE_HIT = getSound("block.nether_gold_ore.hit")
    BLOCK_NETHER_GOLD_ORE_PLACE = getSound("block.nether_gold_ore.place")
    BLOCK_NETHER_GOLD_ORE_STEP = getSound("block.nether_gold_ore.step")
    BLOCK_NETHER_ORE_BREAK = getSound("block.nether_ore.break")
    BLOCK_NETHER_ORE_FALL = getSound("block.nether_ore.fall")
    BLOCK_NETHER_ORE_HIT = getSound("block.nether_ore.hit")
    BLOCK_NETHER_ORE_PLACE = getSound("block.nether_ore.place")
    BLOCK_NETHER_ORE_STEP = getSound("block.nether_ore.step")
    BLOCK_NETHER_SPROUTS_BREAK = getSound("block.nether_sprouts.break")
    BLOCK_NETHER_SPROUTS_FALL = getSound("block.nether_sprouts.fall")
    BLOCK_NETHER_SPROUTS_HIT = getSound("block.nether_sprouts.hit")
    BLOCK_NETHER_SPROUTS_PLACE = getSound("block.nether_sprouts.place")
    BLOCK_NETHER_SPROUTS_STEP = getSound("block.nether_sprouts.step")
    BLOCK_NETHER_WART_BREAK = getSound("block.nether_wart.break")
    BLOCK_NETHER_WOOD_BREAK = getSound("block.nether_wood.break")
    BLOCK_NETHER_WOOD_BUTTON_CLICK_OFF = getSound("block.nether_wood_button.click_off")
    BLOCK_NETHER_WOOD_BUTTON_CLICK_ON = getSound("block.nether_wood_button.click_on")
    BLOCK_NETHER_WOOD_DOOR_CLOSE = getSound("block.nether_wood_door.close")
    BLOCK_NETHER_WOOD_DOOR_OPEN = getSound("block.nether_wood_door.open")
    BLOCK_NETHER_WOOD_FALL = getSound("block.nether_wood.fall")
    BLOCK_NETHER_WOOD_FENCE_GATE_CLOSE = getSound("block.nether_wood_fence_gate.close")
    BLOCK_NETHER_WOOD_FENCE_GATE_OPEN = getSound("block.nether_wood_fence_gate.open")
    BLOCK_NETHER_WOOD_HANGING_SIGN_BREAK = getSound("block.nether_wood_hanging_sign.break")
    BLOCK_NETHER_WOOD_HANGING_SIGN_FALL = getSound("block.nether_wood_hanging_sign.fall")
    BLOCK_NETHER_WOOD_HANGING_SIGN_HIT = getSound("block.nether_wood_hanging_sign.hit")
    BLOCK_NETHER_WOOD_HANGING_SIGN_PLACE = getSound("block.nether_wood_hanging_sign.place")
    BLOCK_NETHER_WOOD_HANGING_SIGN_STEP = getSound("block.nether_wood_hanging_sign.step")
    BLOCK_NETHER_WOOD_HIT = getSound("block.nether_wood.hit")
    BLOCK_NETHER_WOOD_PLACE = getSound("block.nether_wood.place")
    BLOCK_NETHER_WOOD_PRESSURE_PLATE_CLICK_OFF = getSound("block.nether_wood_pressure_plate.click_off")
    BLOCK_NETHER_WOOD_PRESSURE_PLATE_CLICK_ON = getSound("block.nether_wood_pressure_plate.click_on")
    BLOCK_NETHER_WOOD_STEP = getSound("block.nether_wood.step")
    BLOCK_NETHER_WOOD_TRAPDOOR_CLOSE = getSound("block.nether_wood_trapdoor.close")
    BLOCK_NETHER_WOOD_TRAPDOOR_OPEN = getSound("block.nether_wood_trapdoor.open")
    BLOCK_NOTE_BLOCK_BANJO = getSound("block.note_block.banjo")
    BLOCK_NOTE_BLOCK_BASEDRUM = getSound("block.note_block.basedrum")
    BLOCK_NOTE_BLOCK_BASS = getSound("block.note_block.bass")
    BLOCK_NOTE_BLOCK_BELL = getSound("block.note_block.bell")
    BLOCK_NOTE_BLOCK_BIT = getSound("block.note_block.bit")
    BLOCK_NOTE_BLOCK_CHIME = getSound("block.note_block.chime")
    BLOCK_NOTE_BLOCK_COW_BELL = getSound("block.note_block.cow_bell")
    BLOCK_NOTE_BLOCK_DIDGERIDOO = getSound("block.note_block.didgeridoo")
    BLOCK_NOTE_BLOCK_FLUTE = getSound("block.note_block.flute")
    BLOCK_NOTE_BLOCK_GUITAR = getSound("block.note_block.guitar")
    BLOCK_NOTE_BLOCK_HARP = getSound("block.note_block.harp")
    BLOCK_NOTE_BLOCK_HAT = getSound("block.note_block.hat")
    BLOCK_NOTE_BLOCK_IMITATE_CREEPER = getSound("block.note_block.imitate.creeper")
    BLOCK_NOTE_BLOCK_IMITATE_ENDER_DRAGON = getSound("block.note_block.imitate.ender_dragon")
    BLOCK_NOTE_BLOCK_IMITATE_PIGLIN = getSound("block.note_block.imitate.piglin")
    BLOCK_NOTE_BLOCK_IMITATE_SKELETON = getSound("block.note_block.imitate.skeleton")
    BLOCK_NOTE_BLOCK_IMITATE_WITHER_SKELETON = getSound("block.note_block.imitate.wither_skeleton")
    BLOCK_NOTE_BLOCK_IMITATE_ZOMBIE = getSound("block.note_block.imitate.zombie")
    BLOCK_NOTE_BLOCK_IRON_XYLOPHONE = getSound("block.note_block.iron_xylophone")
    BLOCK_NOTE_BLOCK_PLING = getSound("block.note_block.pling")
    BLOCK_NOTE_BLOCK_SNARE = getSound("block.note_block.snare")
    BLOCK_NOTE_BLOCK_XYLOPHONE = getSound("block.note_block.xylophone")
    BLOCK_NYLIUM_BREAK = getSound("block.nylium.break")
    BLOCK_NYLIUM_FALL = getSound("block.nylium.fall")
    BLOCK_NYLIUM_HIT = getSound("block.nylium.hit")
    BLOCK_NYLIUM_PLACE = getSound("block.nylium.place")
    BLOCK_NYLIUM_STEP = getSound("block.nylium.step")
    BLOCK_PACKED_MUD_BREAK = getSound("block.packed_mud.break")
    BLOCK_PACKED_MUD_FALL = getSound("block.packed_mud.fall")
    BLOCK_PACKED_MUD_HIT = getSound("block.packed_mud.hit")
    BLOCK_PACKED_MUD_PLACE = getSound("block.packed_mud.place")
    BLOCK_PACKED_MUD_STEP = getSound("block.packed_mud.step")
    BLOCK_PALE_HANGING_MOSS_IDLE = getSound("block.pale_hanging_moss.idle")
    BLOCK_PINK_PETALS_BREAK = getSound("block.pink_petals.break")
    BLOCK_PINK_PETALS_FALL = getSound("block.pink_petals.fall")
    BLOCK_PINK_PETALS_HIT = getSound("block.pink_petals.hit")
    BLOCK_PINK_PETALS_PLACE = getSound("block.pink_petals.place")
    BLOCK_PINK_PETALS_STEP = getSound("block.pink_petals.step")
    BLOCK_PISTON_CONTRACT = getSound("block.piston.contract")
    BLOCK_PISTON_EXTEND = getSound("block.piston.extend")
    BLOCK_POINTED_DRIPSTONE_BREAK = getSound("block.pointed_dripstone.break")
    BLOCK_POINTED_DRIPSTONE_DRIP_LAVA = getSound("block.pointed_dripstone.drip_lava")
    BLOCK_POINTED_DRIPSTONE_DRIP_LAVA_INTO_CAULDRON = getSound("block.pointed_dripstone.drip_lava_into_cauldron")
    BLOCK_POINTED_DRIPSTONE_DRIP_WATER = getSound("block.pointed_dripstone.drip_water")
    BLOCK_POINTED_DRIPSTONE_DRIP_WATER_INTO_CAULDRON = getSound("block.pointed_dripstone.drip_water_into_cauldron")
    BLOCK_POINTED_DRIPSTONE_FALL = getSound("block.pointed_dripstone.fall")
    BLOCK_POINTED_DRIPSTONE_HIT = getSound("block.pointed_dripstone.hit")
    BLOCK_POINTED_DRIPSTONE_LAND = getSound("block.pointed_dripstone.land")
    BLOCK_POINTED_DRIPSTONE_PLACE = getSound("block.pointed_dripstone.place")
    BLOCK_POINTED_DRIPSTONE_STEP = getSound("block.pointed_dripstone.step")
    BLOCK_POLISHED_DEEPSLATE_BREAK = getSound("block.polished_deepslate.break")
    BLOCK_POLISHED_DEEPSLATE_FALL = getSound("block.polished_deepslate.fall")
    BLOCK_POLISHED_DEEPSLATE_HIT = getSound("block.polished_deepslate.hit")
    BLOCK_POLISHED_DEEPSLATE_PLACE = getSound("block.polished_deepslate.place")
    BLOCK_POLISHED_DEEPSLATE_STEP = getSound("block.polished_deepslate.step")
    BLOCK_POLISHED_TUFF_BREAK = getSound("block.polished_tuff.break")
    BLOCK_POLISHED_TUFF_FALL = getSound("block.polished_tuff.fall")
    BLOCK_POLISHED_TUFF_HIT = getSound("block.polished_tuff.hit")
    BLOCK_POLISHED_TUFF_PLACE = getSound("block.polished_tuff.place")
    BLOCK_POLISHED_TUFF_STEP = getSound("block.polished_tuff.step")
    BLOCK_PORTAL_AMBIENT = getSound("block.portal.ambient")
    BLOCK_PORTAL_TRAVEL = getSound("block.portal.travel")
    BLOCK_PORTAL_TRIGGER = getSound("block.portal.trigger")
    BLOCK_POWDER_SNOW_BREAK = getSound("block.powder_snow.break")
    BLOCK_POWDER_SNOW_FALL = getSound("block.powder_snow.fall")
    BLOCK_POWDER_SNOW_HIT = getSound("block.powder_snow.hit")
    BLOCK_POWDER_SNOW_PLACE = getSound("block.powder_snow.place")
    BLOCK_POWDER_SNOW_STEP = getSound("block.powder_snow.step")
    BLOCK_PUMPKIN_CARVE = getSound("block.pumpkin.carve")
    BLOCK_REDSTONE_TORCH_BURNOUT = getSound("block.redstone_torch.burnout")
    BLOCK_RESIN_BREAK = getSound("block.resin.break")
    BLOCK_RESIN_BRICKS_BREAK = getSound("block.resin_bricks.break")
    BLOCK_RESIN_BRICKS_FALL = getSound("block.resin_bricks.fall")
    BLOCK_RESIN_BRICKS_HIT = getSound("block.resin_bricks.hit")
    BLOCK_RESIN_BRICKS_PLACE = getSound("block.resin_bricks.place")
    BLOCK_RESIN_BRICKS_STEP = getSound("block.resin_bricks.step")
    BLOCK_RESIN_FALL = getSound("block.resin.fall")
    BLOCK_RESIN_PLACE = getSound("block.resin.place")
    BLOCK_RESIN_STEP = getSound("block.resin.step")
    BLOCK_RESPAWN_ANCHOR_AMBIENT = getSound("block.respawn_anchor.ambient")
    BLOCK_RESPAWN_ANCHOR_CHARGE = getSound("block.respawn_anchor.charge")
    BLOCK_RESPAWN_ANCHOR_DEPLETE = getSound("block.respawn_anchor.deplete")
    BLOCK_RESPAWN_ANCHOR_SET_SPAWN = getSound("block.respawn_anchor.set_spawn")
    BLOCK_ROOTED_DIRT_BREAK = getSound("block.rooted_dirt.break")
    BLOCK_ROOTED_DIRT_FALL = getSound("block.rooted_dirt.fall")
    BLOCK_ROOTED_DIRT_HIT = getSound("block.rooted_dirt.hit")
    BLOCK_ROOTED_DIRT_PLACE = getSound("block.rooted_dirt.place")
    BLOCK_ROOTED_DIRT_STEP = getSound("block.rooted_dirt.step")
    BLOCK_ROOTS_BREAK = getSound("block.roots.break")
    BLOCK_ROOTS_FALL = getSound("block.roots.fall")
    BLOCK_ROOTS_HIT = getSound("block.roots.hit")
    BLOCK_ROOTS_PLACE = getSound("block.roots.place")
    BLOCK_ROOTS_STEP = getSound("block.roots.step")
    BLOCK_SAND_BREAK = getSound("block.sand.break")
    BLOCK_SAND_FALL = getSound("block.sand.fall")
    BLOCK_SAND_HIT = getSound("block.sand.hit")
    BLOCK_SAND_PLACE = getSound("block.sand.place")
    BLOCK_SAND_STEP = getSound("block.sand.step")
    BLOCK_SCAFFOLDING_BREAK = getSound("block.scaffolding.break")
    BLOCK_SCAFFOLDING_FALL = getSound("block.scaffolding.fall")
    BLOCK_SCAFFOLDING_HIT = getSound("block.scaffolding.hit")
    BLOCK_SCAFFOLDING_PLACE = getSound("block.scaffolding.place")
    BLOCK_SCAFFOLDING_STEP = getSound("block.scaffolding.step")
    BLOCK_SCULK_BREAK = getSound("block.sculk.break")
    BLOCK_SCULK_CATALYST_BLOOM = getSound("block.sculk_catalyst.bloom")
    BLOCK_SCULK_CATALYST_BREAK = getSound("block.sculk_catalyst.break")
    BLOCK_SCULK_CATALYST_FALL = getSound("block.sculk_catalyst.fall")
    BLOCK_SCULK_CATALYST_HIT = getSound("block.sculk_catalyst.hit")
    BLOCK_SCULK_CATALYST_PLACE = getSound("block.sculk_catalyst.place")
    BLOCK_SCULK_CATALYST_STEP = getSound("block.sculk_catalyst.step")
    BLOCK_SCULK_CHARGE = getSound("block.sculk.charge")
    BLOCK_SCULK_FALL = getSound("block.sculk.fall")
    BLOCK_SCULK_HIT = getSound("block.sculk.hit")
    BLOCK_SCULK_PLACE = getSound("block.sculk.place")
    BLOCK_SCULK_SENSOR_BREAK = getSound("block.sculk_sensor.break")
    BLOCK_SCULK_SENSOR_CLICKING = getSound("block.sculk_sensor.clicking")
    BLOCK_SCULK_SENSOR_CLICKING_STOP = getSound("block.sculk_sensor.clicking_stop")
    BLOCK_SCULK_SENSOR_FALL = getSound("block.sculk_sensor.fall")
    BLOCK_SCULK_SENSOR_HIT = getSound("block.sculk_sensor.hit")
    BLOCK_SCULK_SENSOR_PLACE = getSound("block.sculk_sensor.place")
    BLOCK_SCULK_SENSOR_STEP = getSound("block.sculk_sensor.step")
    BLOCK_SCULK_SHRIEKER_BREAK = getSound("block.sculk_shrieker.break")
    BLOCK_SCULK_SHRIEKER_FALL = getSound("block.sculk_shrieker.fall")
    BLOCK_SCULK_SHRIEKER_HIT = getSound("block.sculk_shrieker.hit")
    BLOCK_SCULK_SHRIEKER_PLACE = getSound("block.sculk_shrieker.place")
    BLOCK_SCULK_SHRIEKER_SHRIEK = getSound("block.sculk_shrieker.shriek")
    BLOCK_SCULK_SHRIEKER_STEP = getSound("block.sculk_shrieker.step")
    BLOCK_SCULK_SPREAD = getSound("block.sculk.spread")
    BLOCK_SCULK_STEP = getSound("block.sculk.step")
    BLOCK_SCULK_VEIN_BREAK = getSound("block.sculk_vein.break")
    BLOCK_SCULK_VEIN_FALL = getSound("block.sculk_vein.fall")
    BLOCK_SCULK_VEIN_HIT = getSound("block.sculk_vein.hit")
    BLOCK_SCULK_VEIN_PLACE = getSound("block.sculk_vein.place")
    BLOCK_SCULK_VEIN_STEP = getSound("block.sculk_vein.step")
    BLOCK_SHROOMLIGHT_BREAK = getSound("block.shroomlight.break")
    BLOCK_SHROOMLIGHT_FALL = getSound("block.shroomlight.fall")
    BLOCK_SHROOMLIGHT_HIT = getSound("block.shroomlight.hit")
    BLOCK_SHROOMLIGHT_PLACE = getSound("block.shroomlight.place")
    BLOCK_SHROOMLIGHT_STEP = getSound("block.shroomlight.step")
    BLOCK_SHULKER_BOX_CLOSE = getSound("block.shulker_box.close")
    BLOCK_SHULKER_BOX_OPEN = getSound("block.shulker_box.open")
    BLOCK_SIGN_WAXED_INTERACT_FAIL = getSound("block.sign.waxed_interact_fail")
    BLOCK_SLIME_BLOCK_BREAK = getSound("block.slime_block.break")
    BLOCK_SLIME_BLOCK_FALL = getSound("block.slime_block.fall")
    BLOCK_SLIME_BLOCK_HIT = getSound("block.slime_block.hit")
    BLOCK_SLIME_BLOCK_PLACE = getSound("block.slime_block.place")
    BLOCK_SLIME_BLOCK_STEP = getSound("block.slime_block.step")
    BLOCK_SMALL_AMETHYST_BUD_BREAK = getSound("block.small_amethyst_bud.break")
    BLOCK_SMALL_AMETHYST_BUD_PLACE = getSound("block.small_amethyst_bud.place")
    BLOCK_SMALL_DRIPLEAF_BREAK = getSound("block.small_dripleaf.break")
    BLOCK_SMALL_DRIPLEAF_FALL = getSound("block.small_dripleaf.fall")
    BLOCK_SMALL_DRIPLEAF_HIT = getSound("block.small_dripleaf.hit")
    BLOCK_SMALL_DRIPLEAF_PLACE = getSound("block.small_dripleaf.place")
    BLOCK_SMALL_DRIPLEAF_STEP = getSound("block.small_dripleaf.step")
    BLOCK_SMITHING_TABLE_USE = getSound("block.smithing_table.use")
    BLOCK_SMOKER_SMOKE = getSound("block.smoker.smoke")
    BLOCK_SNIFFER_EGG_CRACK = getSound("block.sniffer_egg.crack")
    BLOCK_SNIFFER_EGG_HATCH = getSound("block.sniffer_egg.hatch")
    BLOCK_SNIFFER_EGG_PLOP = getSound("block.sniffer_egg.plop")
    BLOCK_SNOW_BREAK = getSound("block.snow.break")
    BLOCK_SNOW_FALL = getSound("block.snow.fall")
    BLOCK_SNOW_HIT = getSound("block.snow.hit")
    BLOCK_SNOW_PLACE = getSound("block.snow.place")
    BLOCK_SNOW_STEP = getSound("block.snow.step")
    BLOCK_SOUL_SAND_BREAK = getSound("block.soul_sand.break")
    BLOCK_SOUL_SAND_FALL = getSound("block.soul_sand.fall")
    BLOCK_SOUL_SAND_HIT = getSound("block.soul_sand.hit")
    BLOCK_SOUL_SAND_PLACE = getSound("block.soul_sand.place")
    BLOCK_SOUL_SAND_STEP = getSound("block.soul_sand.step")
    BLOCK_SOUL_SOIL_BREAK = getSound("block.soul_soil.break")
    BLOCK_SOUL_SOIL_FALL = getSound("block.soul_soil.fall")
    BLOCK_SOUL_SOIL_HIT = getSound("block.soul_soil.hit")
    BLOCK_SOUL_SOIL_PLACE = getSound("block.soul_soil.place")
    BLOCK_SOUL_SOIL_STEP = getSound("block.soul_soil.step")
    BLOCK_SPAWNER_BREAK = getSound("block.spawner.break")
    BLOCK_SPAWNER_FALL = getSound("block.spawner.fall")
    BLOCK_SPAWNER_HIT = getSound("block.spawner.hit")
    BLOCK_SPAWNER_PLACE = getSound("block.spawner.place")
    BLOCK_SPAWNER_STEP = getSound("block.spawner.step")
    BLOCK_SPONGE_ABSORB = getSound("block.sponge.absorb")
    BLOCK_SPONGE_BREAK = getSound("block.sponge.break")
    BLOCK_SPONGE_FALL = getSound("block.sponge.fall")
    BLOCK_SPONGE_HIT = getSound("block.sponge.hit")
    BLOCK_SPONGE_PLACE = getSound("block.sponge.place")
    BLOCK_SPONGE_STEP = getSound("block.sponge.step")
    BLOCK_SPORE_BLOSSOM_BREAK = getSound("block.spore_blossom.break")
    BLOCK_SPORE_BLOSSOM_FALL = getSound("block.spore_blossom.fall")
    BLOCK_SPORE_BLOSSOM_HIT = getSound("block.spore_blossom.hit")
    BLOCK_SPORE_BLOSSOM_PLACE = getSound("block.spore_blossom.place")
    BLOCK_SPORE_BLOSSOM_STEP = getSound("block.spore_blossom.step")
    BLOCK_STEM_BREAK = getSound("block.stem.break")
    BLOCK_STEM_FALL = getSound("block.stem.fall")
    BLOCK_STEM_HIT = getSound("block.stem.hit")
    BLOCK_STEM_PLACE = getSound("block.stem.place")
    BLOCK_STEM_STEP = getSound("block.stem.step")
    BLOCK_STONE_BREAK = getSound("block.stone.break")
    BLOCK_STONE_BUTTON_CLICK_OFF = getSound("block.stone_button.click_off")
    BLOCK_STONE_BUTTON_CLICK_ON = getSound("block.stone_button.click_on")
    BLOCK_STONE_FALL = getSound("block.stone.fall")
    BLOCK_STONE_HIT = getSound("block.stone.hit")
    BLOCK_STONE_PLACE = getSound("block.stone.place")
    BLOCK_STONE_PRESSURE_PLATE_CLICK_OFF = getSound("block.stone_pressure_plate.click_off")
    BLOCK_STONE_PRESSURE_PLATE_CLICK_ON = getSound("block.stone_pressure_plate.click_on")
    BLOCK_STONE_STEP = getSound("block.stone.step")
    BLOCK_SUSPICIOUS_GRAVEL_BREAK = getSound("block.suspicious_gravel.break")
    BLOCK_SUSPICIOUS_GRAVEL_FALL = getSound("block.suspicious_gravel.fall")
    BLOCK_SUSPICIOUS_GRAVEL_HIT = getSound("block.suspicious_gravel.hit")
    BLOCK_SUSPICIOUS_GRAVEL_PLACE = getSound("block.suspicious_gravel.place")
    BLOCK_SUSPICIOUS_GRAVEL_STEP = getSound("block.suspicious_gravel.step")
    BLOCK_SUSPICIOUS_SAND_BREAK = getSound("block.suspicious_sand.break")
    BLOCK_SUSPICIOUS_SAND_FALL = getSound("block.suspicious_sand.fall")
    BLOCK_SUSPICIOUS_SAND_HIT = getSound("block.suspicious_sand.hit")
    BLOCK_SUSPICIOUS_SAND_PLACE = getSound("block.suspicious_sand.place")
    BLOCK_SUSPICIOUS_SAND_STEP = getSound("block.suspicious_sand.step")
    BLOCK_SWEET_BERRY_BUSH_BREAK = getSound("block.sweet_berry_bush.break")
    BLOCK_SWEET_BERRY_BUSH_PICK_BERRIES = getSound("block.sweet_berry_bush.pick_berries")
    BLOCK_SWEET_BERRY_BUSH_PLACE = getSound("block.sweet_berry_bush.place")
    BLOCK_TRIAL_SPAWNER_ABOUT_TO_SPAWN_ITEM = getSound("block.trial_spawner.about_to_spawn_item")
    BLOCK_TRIAL_SPAWNER_AMBIENT = getSound("block.trial_spawner.ambient")
    BLOCK_TRIAL_SPAWNER_AMBIENT_OMINOUS = getSound("block.trial_spawner.ambient_ominous")
    BLOCK_TRIAL_SPAWNER_BREAK = getSound("block.trial_spawner.break")
    BLOCK_TRIAL_SPAWNER_CLOSE_SHUTTER = getSound("block.trial_spawner.close_shutter")
    BLOCK_TRIAL_SPAWNER_DETECT_PLAYER = getSound("block.trial_spawner.detect_player")
    BLOCK_TRIAL_SPAWNER_EJECT_ITEM = getSound("block.trial_spawner.eject_item")
    BLOCK_TRIAL_SPAWNER_FALL = getSound("block.trial_spawner.fall")
    BLOCK_TRIAL_SPAWNER_HIT = getSound("block.trial_spawner.hit")
    BLOCK_TRIAL_SPAWNER_OMINOUS_ACTIVATE = getSound("block.trial_spawner.ominous_activate")
    BLOCK_TRIAL_SPAWNER_OPEN_SHUTTER = getSound("block.trial_spawner.open_shutter")
    BLOCK_TRIAL_SPAWNER_PLACE = getSound("block.trial_spawner.place")
    BLOCK_TRIAL_SPAWNER_SPAWN_ITEM = getSound("block.trial_spawner.spawn_item")
    BLOCK_TRIAL_SPAWNER_SPAWN_ITEM_BEGIN = getSound("block.trial_spawner.spawn_item_begin")
    BLOCK_TRIAL_SPAWNER_SPAWN_MOB = getSound("block.trial_spawner.spawn_mob")
    BLOCK_TRIAL_SPAWNER_STEP = getSound("block.trial_spawner.step")
    BLOCK_TRIPWIRE_ATTACH = getSound("block.tripwire.attach")
    BLOCK_TRIPWIRE_CLICK_OFF = getSound("block.tripwire.click_off")
    BLOCK_TRIPWIRE_CLICK_ON = getSound("block.tripwire.click_on")
    BLOCK_TRIPWIRE_DETACH = getSound("block.tripwire.detach")
    BLOCK_TUFF_BREAK = getSound("block.tuff.break")
    BLOCK_TUFF_BRICKS_BREAK = getSound("block.tuff_bricks.break")
    BLOCK_TUFF_BRICKS_FALL = getSound("block.tuff_bricks.fall")
    BLOCK_TUFF_BRICKS_HIT = getSound("block.tuff_bricks.hit")
    BLOCK_TUFF_BRICKS_PLACE = getSound("block.tuff_bricks.place")
    BLOCK_TUFF_BRICKS_STEP = getSound("block.tuff_bricks.step")
    BLOCK_TUFF_FALL = getSound("block.tuff.fall")
    BLOCK_TUFF_HIT = getSound("block.tuff.hit")
    BLOCK_TUFF_PLACE = getSound("block.tuff.place")
    BLOCK_TUFF_STEP = getSound("block.tuff.step")
    BLOCK_VAULT_ACTIVATE = getSound("block.vault.activate")
    BLOCK_VAULT_AMBIENT = getSound("block.vault.ambient")
    BLOCK_VAULT_BREAK = getSound("block.vault.break")
    BLOCK_VAULT_CLOSE_SHUTTER = getSound("block.vault.close_shutter")
    BLOCK_VAULT_DEACTIVATE = getSound("block.vault.deactivate")
    BLOCK_VAULT_EJECT_ITEM = getSound("block.vault.eject_item")
    BLOCK_VAULT_FALL = getSound("block.vault.fall")
    BLOCK_VAULT_HIT = getSound("block.vault.hit")
    BLOCK_VAULT_INSERT_ITEM = getSound("block.vault.insert_item")
    BLOCK_VAULT_INSERT_ITEM_FAIL = getSound("block.vault.insert_item_fail")
    BLOCK_VAULT_OPEN_SHUTTER = getSound("block.vault.open_shutter")
    BLOCK_VAULT_PLACE = getSound("block.vault.place")
    BLOCK_VAULT_REJECT_REWARDED_PLAYER = getSound("block.vault.reject_rewarded_player")
    BLOCK_VAULT_STEP = getSound("block.vault.step")
    BLOCK_VINE_BREAK = getSound("block.vine.break")
    BLOCK_VINE_FALL = getSound("block.vine.fall")
    BLOCK_VINE_HIT = getSound("block.vine.hit")
    BLOCK_VINE_PLACE = getSound("block.vine.place")
    BLOCK_VINE_STEP = getSound("block.vine.step")
    BLOCK_WART_BLOCK_BREAK = getSound("block.wart_block.break")
    BLOCK_WART_BLOCK_FALL = getSound("block.wart_block.fall")
    BLOCK_WART_BLOCK_HIT = getSound("block.wart_block.hit")
    BLOCK_WART_BLOCK_PLACE = getSound("block.wart_block.place")
    BLOCK_WART_BLOCK_STEP = getSound("block.wart_block.step")
    BLOCK_WATER_AMBIENT = getSound("block.water.ambient")
    BLOCK_WEEPING_VINES_BREAK = getSound("block.weeping_vines.break")
    BLOCK_WEEPING_VINES_FALL = getSound("block.weeping_vines.fall")
    BLOCK_WEEPING_VINES_HIT = getSound("block.weeping_vines.hit")
    BLOCK_WEEPING_VINES_PLACE = getSound("block.weeping_vines.place")
    BLOCK_WEEPING_VINES_STEP = getSound("block.weeping_vines.step")
    BLOCK_WET_GRASS_BREAK = getSound("block.wet_grass.break")
    BLOCK_WET_GRASS_FALL = getSound("block.wet_grass.fall")
    BLOCK_WET_GRASS_HIT = getSound("block.wet_grass.hit")
    BLOCK_WET_GRASS_PLACE = getSound("block.wet_grass.place")
    BLOCK_WET_GRASS_STEP = getSound("block.wet_grass.step")
    BLOCK_WET_SPONGE_BREAK = getSound("block.wet_sponge.break")
    BLOCK_WET_SPONGE_DRIES = getSound("block.wet_sponge.dries")
    BLOCK_WET_SPONGE_FALL = getSound("block.wet_sponge.fall")
    BLOCK_WET_SPONGE_HIT = getSound("block.wet_sponge.hit")
    BLOCK_WET_SPONGE_PLACE = getSound("block.wet_sponge.place")
    BLOCK_WET_SPONGE_STEP = getSound("block.wet_sponge.step")
    BLOCK_WOODEN_BUTTON_CLICK_OFF = getSound("block.wooden_button.click_off")
    BLOCK_WOODEN_BUTTON_CLICK_ON = getSound("block.wooden_button.click_on")
    BLOCK_WOODEN_DOOR_CLOSE = getSound("block.wooden_door.close")
    BLOCK_WOODEN_DOOR_OPEN = getSound("block.wooden_door.open")
    BLOCK_WOODEN_PRESSURE_PLATE_CLICK_OFF = getSound("block.wooden_pressure_plate.click_off")
    BLOCK_WOODEN_PRESSURE_PLATE_CLICK_ON = getSound("block.wooden_pressure_plate.click_on")
    BLOCK_WOODEN_TRAPDOOR_CLOSE = getSound("block.wooden_trapdoor.close")
    BLOCK_WOODEN_TRAPDOOR_OPEN = getSound("block.wooden_trapdoor.open")
    BLOCK_WOOD_BREAK = getSound("block.wood.break")
    BLOCK_WOOD_FALL = getSound("block.wood.fall")
    BLOCK_WOOD_HIT = getSound("block.wood.hit")
    BLOCK_WOOD_PLACE = getSound("block.wood.place")
    BLOCK_WOOD_STEP = getSound("block.wood.step")
    BLOCK_WOOL_BREAK = getSound("block.wool.break")
    BLOCK_WOOL_FALL = getSound("block.wool.fall")
    BLOCK_WOOL_HIT = getSound("block.wool.hit")
    BLOCK_WOOL_PLACE = getSound("block.wool.place")
    BLOCK_WOOL_STEP = getSound("block.wool.step")
    ENCHANT_THORNS_HIT = getSound("enchant.thorns.hit")
    ENTITY_ALLAY_AMBIENT_WITHOUT_ITEM = getSound("entity.allay.ambient_without_item")
    ENTITY_ALLAY_AMBIENT_WITH_ITEM = getSound("entity.allay.ambient_with_item")
    ENTITY_ALLAY_DEATH = getSound("entity.allay.death")
    ENTITY_ALLAY_HURT = getSound("entity.allay.hurt")
    ENTITY_ALLAY_ITEM_GIVEN = getSound("entity.allay.item_given")
    ENTITY_ALLAY_ITEM_TAKEN = getSound("entity.allay.item_taken")
    ENTITY_ALLAY_ITEM_THROWN = getSound("entity.allay.item_thrown")
    ENTITY_ARMADILLO_AMBIENT = getSound("entity.armadillo.ambient")
    ENTITY_ARMADILLO_BRUSH = getSound("entity.armadillo.brush")
    ENTITY_ARMADILLO_DEATH = getSound("entity.armadillo.death")
    ENTITY_ARMADILLO_EAT = getSound("entity.armadillo.eat")
    ENTITY_ARMADILLO_HURT = getSound("entity.armadillo.hurt")
    ENTITY_ARMADILLO_HURT_REDUCED = getSound("entity.armadillo.hurt_reduced")
    ENTITY_ARMADILLO_LAND = getSound("entity.armadillo.land")
    ENTITY_ARMADILLO_PEEK = getSound("entity.armadillo.peek")
    ENTITY_ARMADILLO_ROLL = getSound("entity.armadillo.roll")
    ENTITY_ARMADILLO_SCUTE_DROP = getSound("entity.armadillo.scute_drop")
    ENTITY_ARMADILLO_STEP = getSound("entity.armadillo.step")
    ENTITY_ARMADILLO_UNROLL_FINISH = getSound("entity.armadillo.unroll_finish")
    ENTITY_ARMADILLO_UNROLL_START = getSound("entity.armadillo.unroll_start")
    ENTITY_ARMOR_STAND_BREAK = getSound("entity.armor_stand.break")
    ENTITY_ARMOR_STAND_FALL = getSound("entity.armor_stand.fall")
    ENTITY_ARMOR_STAND_HIT = getSound("entity.armor_stand.hit")
    ENTITY_ARMOR_STAND_PLACE = getSound("entity.armor_stand.place")
    ENTITY_ARROW_HIT = getSound("entity.arrow.hit")
    ENTITY_ARROW_HIT_PLAYER = getSound("entity.arrow.hit_player")
    ENTITY_ARROW_SHOOT = getSound("entity.arrow.shoot")
    ENTITY_AXOLOTL_ATTACK = getSound("entity.axolotl.attack")
    ENTITY_AXOLOTL_DEATH = getSound("entity.axolotl.death")
    ENTITY_AXOLOTL_HURT = getSound("entity.axolotl.hurt")
    ENTITY_AXOLOTL_IDLE_AIR = getSound("entity.axolotl.idle_air")
    ENTITY_AXOLOTL_IDLE_WATER = getSound("entity.axolotl.idle_water")
    ENTITY_AXOLOTL_SPLASH = getSound("entity.axolotl.splash")
    ENTITY_AXOLOTL_SWIM = getSound("entity.axolotl.swim")
    ENTITY_BAT_AMBIENT = getSound("entity.bat.ambient")
    ENTITY_BAT_DEATH = getSound("entity.bat.death")
    ENTITY_BAT_HURT = getSound("entity.bat.hurt")
    ENTITY_BAT_LOOP = getSound("entity.bat.loop")
    ENTITY_BAT_TAKEOFF = getSound("entity.bat.takeoff")
    ENTITY_BEE_DEATH = getSound("entity.bee.death")
    ENTITY_BEE_HURT = getSound("entity.bee.hurt")
    ENTITY_BEE_LOOP = getSound("entity.bee.loop")
    ENTITY_BEE_LOOP_AGGRESSIVE = getSound("entity.bee.loop_aggressive")
    ENTITY_BEE_POLLINATE = getSound("entity.bee.pollinate")
    ENTITY_BEE_STING = getSound("entity.bee.sting")
    ENTITY_BLAZE_AMBIENT = getSound("entity.blaze.ambient")
    ENTITY_BLAZE_BURN = getSound("entity.blaze.burn")
    ENTITY_BLAZE_DEATH = getSound("entity.blaze.death")
    ENTITY_BLAZE_HURT = getSound("entity.blaze.hurt")
    ENTITY_BLAZE_SHOOT = getSound("entity.blaze.shoot")
    ENTITY_BOAT_PADDLE_LAND = getSound("entity.boat.paddle_land")
    ENTITY_BOAT_PADDLE_WATER = getSound("entity.boat.paddle_water")
    ENTITY_BOGGED_AMBIENT = getSound("entity.bogged.ambient")
    ENTITY_BOGGED_DEATH = getSound("entity.bogged.death")
    ENTITY_BOGGED_HURT = getSound("entity.bogged.hurt")
    ENTITY_BOGGED_SHEAR = getSound("entity.bogged.shear")
    ENTITY_BOGGED_STEP = getSound("entity.bogged.step")
    ENTITY_BREEZE_CHARGE = getSound("entity.breeze.charge")
    ENTITY_BREEZE_DEATH = getSound("entity.breeze.death")
    ENTITY_BREEZE_DEFLECT = getSound("entity.breeze.deflect")
    ENTITY_BREEZE_HURT = getSound("entity.breeze.hurt")
    ENTITY_BREEZE_IDLE_AIR = getSound("entity.breeze.idle_air")
    ENTITY_BREEZE_IDLE_GROUND = getSound("entity.breeze.idle_ground")
    ENTITY_BREEZE_INHALE = getSound("entity.breeze.inhale")
    ENTITY_BREEZE_JUMP = getSound("entity.breeze.jump")
    ENTITY_BREEZE_LAND = getSound("entity.breeze.land")
    ENTITY_BREEZE_SHOOT = getSound("entity.breeze.shoot")
    ENTITY_BREEZE_SLIDE = getSound("entity.breeze.slide")
    ENTITY_BREEZE_WHIRL = getSound("entity.breeze.whirl")
    ENTITY_BREEZE_WIND_BURST = getSound("entity.breeze.wind_burst")
    ENTITY_CAMEL_AMBIENT = getSound("entity.camel.ambient")
    ENTITY_CAMEL_DASH = getSound("entity.camel.dash")
    ENTITY_CAMEL_DASH_READY = getSound("entity.camel.dash_ready")
    ENTITY_CAMEL_DEATH = getSound("entity.camel.death")
    ENTITY_CAMEL_EAT = getSound("entity.camel.eat")
    ENTITY_CAMEL_HURT = getSound("entity.camel.hurt")
    ENTITY_CAMEL_SADDLE = getSound("entity.camel.saddle")
    ENTITY_CAMEL_SIT = getSound("entity.camel.sit")
    ENTITY_CAMEL_STAND = getSound("entity.camel.stand")
    ENTITY_CAMEL_STEP = getSound("entity.camel.step")
    ENTITY_CAMEL_STEP_SAND = getSound("entity.camel.step_sand")
    ENTITY_CAT_AMBIENT = getSound("entity.cat.ambient")
    ENTITY_CAT_BEG_FOR_FOOD = getSound("entity.cat.beg_for_food")
    ENTITY_CAT_DEATH = getSound("entity.cat.death")
    ENTITY_CAT_EAT = getSound("entity.cat.eat")
    ENTITY_CAT_HISS = getSound("entity.cat.hiss")
    ENTITY_CAT_HURT = getSound("entity.cat.hurt")
    ENTITY_CAT_PURR = getSound("entity.cat.purr")
    ENTITY_CAT_PURREOW = getSound("entity.cat.purreow")
    ENTITY_CAT_STRAY_AMBIENT = getSound("entity.cat.stray_ambient")
    ENTITY_CHICKEN_AMBIENT = getSound("entity.chicken.ambient")
    ENTITY_CHICKEN_DEATH = getSound("entity.chicken.death")
    ENTITY_CHICKEN_EGG = getSound("entity.chicken.egg")
    ENTITY_CHICKEN_HURT = getSound("entity.chicken.hurt")
    ENTITY_CHICKEN_STEP = getSound("entity.chicken.step")
    ENTITY_COD_AMBIENT = getSound("entity.cod.ambient")
    ENTITY_COD_DEATH = getSound("entity.cod.death")
    ENTITY_COD_FLOP = getSound("entity.cod.flop")
    ENTITY_COD_HURT = getSound("entity.cod.hurt")
    ENTITY_COW_AMBIENT = getSound("entity.cow.ambient")
    ENTITY_COW_DEATH = getSound("entity.cow.death")
    ENTITY_COW_HURT = getSound("entity.cow.hurt")
    ENTITY_COW_MILK = getSound("entity.cow.milk")
    ENTITY_COW_STEP = getSound("entity.cow.step")
    ENTITY_CREAKING_ACTIVATE = getSound("entity.creaking.activate")
    ENTITY_CREAKING_AMBIENT = getSound("entity.creaking.ambient")
    ENTITY_CREAKING_ATTACK = getSound("entity.creaking.attack")
    ENTITY_CREAKING_DEACTIVATE = getSound("entity.creaking.deactivate")
    ENTITY_CREAKING_DEATH = getSound("entity.creaking.death")
    ENTITY_CREAKING_FREEZE = getSound("entity.creaking.freeze")
    ENTITY_CREAKING_SPAWN = getSound("entity.creaking.spawn")
    ENTITY_CREAKING_STEP = getSound("entity.creaking.step")
    ENTITY_CREAKING_SWAY = getSound("entity.creaking.sway")
    ENTITY_CREAKING_TWITCH = getSound("entity.creaking.twitch")
    ENTITY_CREAKING_UNFREEZE = getSound("entity.creaking.unfreeze")
    ENTITY_CREEPER_DEATH = getSound("entity.creeper.death")
    ENTITY_CREEPER_HURT = getSound("entity.creeper.hurt")
    ENTITY_CREEPER_PRIMED = getSound("entity.creeper.primed")
    ENTITY_DOLPHIN_AMBIENT = getSound("entity.dolphin.ambient")
    ENTITY_DOLPHIN_AMBIENT_WATER = getSound("entity.dolphin.ambient_water")
    ENTITY_DOLPHIN_ATTACK = getSound("entity.dolphin.attack")
    ENTITY_DOLPHIN_DEATH = getSound("entity.dolphin.death")
    ENTITY_DOLPHIN_EAT = getSound("entity.dolphin.eat")
    ENTITY_DOLPHIN_HURT = getSound("entity.dolphin.hurt")
    ENTITY_DOLPHIN_JUMP = getSound("entity.dolphin.jump")
    ENTITY_DOLPHIN_PLAY = getSound("entity.dolphin.play")
    ENTITY_DOLPHIN_SPLASH = getSound("entity.dolphin.splash")
    ENTITY_DOLPHIN_SWIM = getSound("entity.dolphin.swim")
    ENTITY_DONKEY_AMBIENT = getSound("entity.donkey.ambient")
    ENTITY_DONKEY_ANGRY = getSound("entity.donkey.angry")
    ENTITY_DONKEY_CHEST = getSound("entity.donkey.chest")
    ENTITY_DONKEY_DEATH = getSound("entity.donkey.death")
    ENTITY_DONKEY_EAT = getSound("entity.donkey.eat")
    ENTITY_DONKEY_HURT = getSound("entity.donkey.hurt")
    ENTITY_DONKEY_JUMP = getSound("entity.donkey.jump")
    ENTITY_DRAGON_FIREBALL_EXPLODE = getSound("entity.dragon_fireball.explode")
    ENTITY_DROWNED_AMBIENT = getSound("entity.drowned.ambient")
    ENTITY_DROWNED_AMBIENT_WATER = getSound("entity.drowned.ambient_water")
    ENTITY_DROWNED_DEATH = getSound("entity.drowned.death")
    ENTITY_DROWNED_DEATH_WATER = getSound("entity.drowned.death_water")
    ENTITY_DROWNED_HURT = getSound("entity.drowned.hurt")
    ENTITY_DROWNED_HURT_WATER = getSound("entity.drowned.hurt_water")
    ENTITY_DROWNED_SHOOT = getSound("entity.drowned.shoot")
    ENTITY_DROWNED_STEP = getSound("entity.drowned.step")
    ENTITY_DROWNED_SWIM = getSound("entity.drowned.swim")
    ENTITY_EGG_THROW = getSound("entity.egg.throw")
    ENTITY_ELDER_GUARDIAN_AMBIENT = getSound("entity.elder_guardian.ambient")
    ENTITY_ELDER_GUARDIAN_AMBIENT_LAND = getSound("entity.elder_guardian.ambient_land")
    ENTITY_ELDER_GUARDIAN_CURSE = getSound("entity.elder_guardian.curse")
    ENTITY_ELDER_GUARDIAN_DEATH = getSound("entity.elder_guardian.death")
    ENTITY_ELDER_GUARDIAN_DEATH_LAND = getSound("entity.elder_guardian.death_land")
    ENTITY_ELDER_GUARDIAN_FLOP = getSound("entity.elder_guardian.flop")
    ENTITY_ELDER_GUARDIAN_HURT = getSound("entity.elder_guardian.hurt")
    ENTITY_ELDER_GUARDIAN_HURT_LAND = getSound("entity.elder_guardian.hurt_land")
    ENTITY_ENDERMAN_AMBIENT = getSound("entity.enderman.ambient")
    ENTITY_ENDERMAN_DEATH = getSound("entity.enderman.death")
    ENTITY_ENDERMAN_HURT = getSound("entity.enderman.hurt")
    ENTITY_ENDERMAN_SCREAM = getSound("entity.enderman.scream")
    ENTITY_ENDERMAN_STARE = getSound("entity.enderman.stare")
    ENTITY_ENDERMAN_TELEPORT = getSound("entity.enderman.teleport")
    ENTITY_ENDERMITE_AMBIENT = getSound("entity.endermite.ambient")
    ENTITY_ENDERMITE_DEATH = getSound("entity.endermite.death")
    ENTITY_ENDERMITE_HURT = getSound("entity.endermite.hurt")
    ENTITY_ENDERMITE_STEP = getSound("entity.endermite.step")
    ENTITY_ENDER_DRAGON_AMBIENT = getSound("entity.ender_dragon.ambient")
    ENTITY_ENDER_DRAGON_DEATH = getSound("entity.ender_dragon.death")
    ENTITY_ENDER_DRAGON_FLAP = getSound("entity.ender_dragon.flap")
    ENTITY_ENDER_DRAGON_GROWL = getSound("entity.ender_dragon.growl")
    ENTITY_ENDER_DRAGON_HURT = getSound("entity.ender_dragon.hurt")
    ENTITY_ENDER_DRAGON_SHOOT = getSound("entity.ender_dragon.shoot")
    ENTITY_ENDER_EYE_DEATH = getSound("entity.ender_eye.death")
    ENTITY_ENDER_EYE_LAUNCH = getSound("entity.ender_eye.launch")
    ENTITY_ENDER_PEARL_THROW = getSound("entity.ender_pearl.throw")
    ENTITY_EVOKER_AMBIENT = getSound("entity.evoker.ambient")
    ENTITY_EVOKER_CAST_SPELL = getSound("entity.evoker.cast_spell")
    ENTITY_EVOKER_CELEBRATE = getSound("entity.evoker.celebrate")
    ENTITY_EVOKER_DEATH = getSound("entity.evoker.death")
    ENTITY_EVOKER_FANGS_ATTACK = getSound("entity.evoker_fangs.attack")
    ENTITY_EVOKER_HURT = getSound("entity.evoker.hurt")
    ENTITY_EVOKER_PREPARE_ATTACK = getSound("entity.evoker.prepare_attack")
    ENTITY_EVOKER_PREPARE_SUMMON = getSound("entity.evoker.prepare_summon")
    ENTITY_EVOKER_PREPARE_WOLOLO = getSound("entity.evoker.prepare_wololo")
    ENTITY_EXPERIENCE_BOTTLE_THROW = getSound("entity.experience_bottle.throw")
    ENTITY_EXPERIENCE_ORB_PICKUP = getSound("entity.experience_orb.pickup")
    ENTITY_FIREWORK_ROCKET_BLAST = getSound("entity.firework_rocket.blast")
    ENTITY_FIREWORK_ROCKET_BLAST_FAR = getSound("entity.firework_rocket.blast_far")
    ENTITY_FIREWORK_ROCKET_LARGE_BLAST = getSound("entity.firework_rocket.large_blast")
    ENTITY_FIREWORK_ROCKET_LARGE_BLAST_FAR = getSound("entity.firework_rocket.large_blast_far")
    ENTITY_FIREWORK_ROCKET_LAUNCH = getSound("entity.firework_rocket.launch")
    ENTITY_FIREWORK_ROCKET_SHOOT = getSound("entity.firework_rocket.shoot")
    ENTITY_FIREWORK_ROCKET_TWINKLE = getSound("entity.firework_rocket.twinkle")
    ENTITY_FIREWORK_ROCKET_TWINKLE_FAR = getSound("entity.firework_rocket.twinkle_far")
    ENTITY_FISHING_BOBBER_RETRIEVE = getSound("entity.fishing_bobber.retrieve")
    ENTITY_FISHING_BOBBER_SPLASH = getSound("entity.fishing_bobber.splash")
    ENTITY_FISHING_BOBBER_THROW = getSound("entity.fishing_bobber.throw")
    ENTITY_FISH_SWIM = getSound("entity.fish.swim")
    ENTITY_FOX_AGGRO = getSound("entity.fox.aggro")
    ENTITY_FOX_AMBIENT = getSound("entity.fox.ambient")
    ENTITY_FOX_BITE = getSound("entity.fox.bite")
    ENTITY_FOX_DEATH = getSound("entity.fox.death")
    ENTITY_FOX_EAT = getSound("entity.fox.eat")
    ENTITY_FOX_HURT = getSound("entity.fox.hurt")
    ENTITY_FOX_SCREECH = getSound("entity.fox.screech")
    ENTITY_FOX_SLEEP = getSound("entity.fox.sleep")
    ENTITY_FOX_SNIFF = getSound("entity.fox.sniff")
    ENTITY_FOX_SPIT = getSound("entity.fox.spit")
    ENTITY_FOX_TELEPORT = getSound("entity.fox.teleport")
    ENTITY_FROG_AMBIENT = getSound("entity.frog.ambient")
    ENTITY_FROG_DEATH = getSound("entity.frog.death")
    ENTITY_FROG_EAT = getSound("entity.frog.eat")
    ENTITY_FROG_HURT = getSound("entity.frog.hurt")
    ENTITY_FROG_LAY_SPAWN = getSound("entity.frog.lay_spawn")
    ENTITY_FROG_LONG_JUMP = getSound("entity.frog.long_jump")
    ENTITY_FROG_STEP = getSound("entity.frog.step")
    ENTITY_FROG_TONGUE = getSound("entity.frog.tongue")
    ENTITY_GENERIC_BIG_FALL = getSound("entity.generic.big_fall")
    ENTITY_GENERIC_BURN = getSound("entity.generic.burn")
    ENTITY_GENERIC_DEATH = getSound("entity.generic.death")
    ENTITY_GENERIC_DRINK = getSound("entity.generic.drink")
    ENTITY_GENERIC_EAT = getSound("entity.generic.eat")
    ENTITY_GENERIC_EXPLODE = getSound("entity.generic.explode")
    ENTITY_GENERIC_EXTINGUISH_FIRE = getSound("entity.generic.extinguish_fire")
    ENTITY_GENERIC_HURT = getSound("entity.generic.hurt")
    ENTITY_GENERIC_SMALL_FALL = getSound("entity.generic.small_fall")
    ENTITY_GENERIC_SPLASH = getSound("entity.generic.splash")
    ENTITY_GENERIC_SWIM = getSound("entity.generic.swim")
    ENTITY_GHAST_AMBIENT = getSound("entity.ghast.ambient")
    ENTITY_GHAST_DEATH = getSound("entity.ghast.death")
    ENTITY_GHAST_HURT = getSound("entity.ghast.hurt")
    ENTITY_GHAST_SCREAM = getSound("entity.ghast.scream")
    ENTITY_GHAST_SHOOT = getSound("entity.ghast.shoot")
    ENTITY_GHAST_WARN = getSound("entity.ghast.warn")
    ENTITY_GLOW_ITEM_FRAME_ADD_ITEM = getSound("entity.glow_item_frame.add_item")
    ENTITY_GLOW_ITEM_FRAME_BREAK = getSound("entity.glow_item_frame.break")
    ENTITY_GLOW_ITEM_FRAME_PLACE = getSound("entity.glow_item_frame.place")
    ENTITY_GLOW_ITEM_FRAME_REMOVE_ITEM = getSound("entity.glow_item_frame.remove_item")
    ENTITY_GLOW_ITEM_FRAME_ROTATE_ITEM = getSound("entity.glow_item_frame.rotate_item")
    ENTITY_GLOW_SQUID_AMBIENT = getSound("entity.glow_squid.ambient")
    ENTITY_GLOW_SQUID_DEATH = getSound("entity.glow_squid.death")
    ENTITY_GLOW_SQUID_HURT = getSound("entity.glow_squid.hurt")
    ENTITY_GLOW_SQUID_SQUIRT = getSound("entity.glow_squid.squirt")
    ENTITY_GOAT_AMBIENT = getSound("entity.goat.ambient")
    ENTITY_GOAT_DEATH = getSound("entity.goat.death")
    ENTITY_GOAT_EAT = getSound("entity.goat.eat")
    ENTITY_GOAT_HORN_BREAK = getSound("entity.goat.horn_break")
    ENTITY_GOAT_HURT = getSound("entity.goat.hurt")
    ENTITY_GOAT_LONG_JUMP = getSound("entity.goat.long_jump")
    ENTITY_GOAT_MILK = getSound("entity.goat.milk")
    ENTITY_GOAT_PREPARE_RAM = getSound("entity.goat.prepare_ram")
    ENTITY_GOAT_RAM_IMPACT = getSound("entity.goat.ram_impact")
    ENTITY_GOAT_SCREAMING_AMBIENT = getSound("entity.goat.screaming.ambient")
    ENTITY_GOAT_SCREAMING_DEATH = getSound("entity.goat.screaming.death")
    ENTITY_GOAT_SCREAMING_EAT = getSound("entity.goat.screaming.eat")
    ENTITY_GOAT_SCREAMING_HURT = getSound("entity.goat.screaming.hurt")
    ENTITY_GOAT_SCREAMING_LONG_JUMP = getSound("entity.goat.screaming.long_jump")
    ENTITY_GOAT_SCREAMING_MILK = getSound("entity.goat.screaming.milk")
    ENTITY_GOAT_SCREAMING_PREPARE_RAM = getSound("entity.goat.screaming.prepare_ram")
    ENTITY_GOAT_SCREAMING_RAM_IMPACT = getSound("entity.goat.screaming.ram_impact")
    ENTITY_GOAT_STEP = getSound("entity.goat.step")
    ENTITY_GUARDIAN_AMBIENT = getSound("entity.guardian.ambient")
    ENTITY_GUARDIAN_AMBIENT_LAND = getSound("entity.guardian.ambient_land")
    ENTITY_GUARDIAN_ATTACK = getSound("entity.guardian.attack")
    ENTITY_GUARDIAN_DEATH = getSound("entity.guardian.death")
    ENTITY_GUARDIAN_DEATH_LAND = getSound("entity.guardian.death_land")
    ENTITY_GUARDIAN_FLOP = getSound("entity.guardian.flop")
    ENTITY_GUARDIAN_HURT = getSound("entity.guardian.hurt")
    ENTITY_GUARDIAN_HURT_LAND = getSound("entity.guardian.hurt_land")
    ENTITY_HOGLIN_AMBIENT = getSound("entity.hoglin.ambient")
    ENTITY_HOGLIN_ANGRY = getSound("entity.hoglin.angry")
    ENTITY_HOGLIN_ATTACK = getSound("entity.hoglin.attack")
    ENTITY_HOGLIN_CONVERTED_TO_ZOMBIFIED = getSound("entity.hoglin.converted_to_zombified")
    ENTITY_HOGLIN_DEATH = getSound("entity.hoglin.death")
    ENTITY_HOGLIN_HURT = getSound("entity.hoglin.hurt")
    ENTITY_HOGLIN_RETREAT = getSound("entity.hoglin.retreat")
    ENTITY_HOGLIN_STEP = getSound("entity.hoglin.step")
    ENTITY_HORSE_AMBIENT = getSound("entity.horse.ambient")
    ENTITY_HORSE_ANGRY = getSound("entity.horse.angry")
    ENTITY_HORSE_ARMOR = getSound("entity.horse.armor")
    ENTITY_HORSE_BREATHE = getSound("entity.horse.breathe")
    ENTITY_HORSE_DEATH = getSound("entity.horse.death")
    ENTITY_HORSE_EAT = getSound("entity.horse.eat")
    ENTITY_HORSE_GALLOP = getSound("entity.horse.gallop")
    ENTITY_HORSE_HURT = getSound("entity.horse.hurt")
    ENTITY_HORSE_JUMP = getSound("entity.horse.jump")
    ENTITY_HORSE_LAND = getSound("entity.horse.land")
    ENTITY_HORSE_SADDLE = getSound("entity.horse.saddle")
    ENTITY_HORSE_STEP = getSound("entity.horse.step")
    ENTITY_HORSE_STEP_WOOD = getSound("entity.horse.step_wood")
    ENTITY_HOSTILE_BIG_FALL = getSound("entity.hostile.big_fall")
    ENTITY_HOSTILE_DEATH = getSound("entity.hostile.death")
    ENTITY_HOSTILE_HURT = getSound("entity.hostile.hurt")
    ENTITY_HOSTILE_SMALL_FALL = getSound("entity.hostile.small_fall")
    ENTITY_HOSTILE_SPLASH = getSound("entity.hostile.splash")
    ENTITY_HOSTILE_SWIM = getSound("entity.hostile.swim")
    ENTITY_HUSK_AMBIENT = getSound("entity.husk.ambient")
    ENTITY_HUSK_CONVERTED_TO_ZOMBIE = getSound("entity.husk.converted_to_zombie")
    ENTITY_HUSK_DEATH = getSound("entity.husk.death")
    ENTITY_HUSK_HURT = getSound("entity.husk.hurt")
    ENTITY_HUSK_STEP = getSound("entity.husk.step")
    ENTITY_ILLUSIONER_AMBIENT = getSound("entity.illusioner.ambient")
    ENTITY_ILLUSIONER_CAST_SPELL = getSound("entity.illusioner.cast_spell")
    ENTITY_ILLUSIONER_DEATH = getSound("entity.illusioner.death")
    ENTITY_ILLUSIONER_HURT = getSound("entity.illusioner.hurt")
    ENTITY_ILLUSIONER_MIRROR_MOVE = getSound("entity.illusioner.mirror_move")
    ENTITY_ILLUSIONER_PREPARE_BLINDNESS = getSound("entity.illusioner.prepare_blindness")
    ENTITY_ILLUSIONER_PREPARE_MIRROR = getSound("entity.illusioner.prepare_mirror")
    ENTITY_IRON_GOLEM_ATTACK = getSound("entity.iron_golem.attack")
    ENTITY_IRON_GOLEM_DAMAGE = getSound("entity.iron_golem.damage")
    ENTITY_IRON_GOLEM_DEATH = getSound("entity.iron_golem.death")
    ENTITY_IRON_GOLEM_HURT = getSound("entity.iron_golem.hurt")
    ENTITY_IRON_GOLEM_REPAIR = getSound("entity.iron_golem.repair")
    ENTITY_IRON_GOLEM_STEP = getSound("entity.iron_golem.step")
    ENTITY_ITEM_BREAK = getSound("entity.item.break")
    ENTITY_ITEM_FRAME_ADD_ITEM = getSound("entity.item_frame.add_item")
    ENTITY_ITEM_FRAME_BREAK = getSound("entity.item_frame.break")
    ENTITY_ITEM_FRAME_PLACE = getSound("entity.item_frame.place")
    ENTITY_ITEM_FRAME_REMOVE_ITEM = getSound("entity.item_frame.remove_item")
    ENTITY_ITEM_FRAME_ROTATE_ITEM = getSound("entity.item_frame.rotate_item")
    ENTITY_ITEM_PICKUP = getSound("entity.item.pickup")
    ENTITY_LEASH_KNOT_BREAK = getSound("entity.leash_knot.break")
    ENTITY_LEASH_KNOT_PLACE = getSound("entity.leash_knot.place")
    ENTITY_LIGHTNING_BOLT_IMPACT = getSound("entity.lightning_bolt.impact")
    ENTITY_LIGHTNING_BOLT_THUNDER = getSound("entity.lightning_bolt.thunder")
    ENTITY_LINGERING_POTION_THROW = getSound("entity.lingering_potion.throw")
    ENTITY_LLAMA_AMBIENT = getSound("entity.llama.ambient")
    ENTITY_LLAMA_ANGRY = getSound("entity.llama.angry")
    ENTITY_LLAMA_CHEST = getSound("entity.llama.chest")
    ENTITY_LLAMA_DEATH = getSound("entity.llama.death")
    ENTITY_LLAMA_EAT = getSound("entity.llama.eat")
    ENTITY_LLAMA_HURT = getSound("entity.llama.hurt")
    ENTITY_LLAMA_SPIT = getSound("entity.llama.spit")
    ENTITY_LLAMA_STEP = getSound("entity.llama.step")
    ENTITY_LLAMA_SWAG = getSound("entity.llama.swag")
    ENTITY_MAGMA_CUBE_DEATH = getSound("entity.magma_cube.death")
    ENTITY_MAGMA_CUBE_DEATH_SMALL = getSound("entity.magma_cube.death_small")
    ENTITY_MAGMA_CUBE_HURT = getSound("entity.magma_cube.hurt")
    ENTITY_MAGMA_CUBE_HURT_SMALL = getSound("entity.magma_cube.hurt_small")
    ENTITY_MAGMA_CUBE_JUMP = getSound("entity.magma_cube.jump")
    ENTITY_MAGMA_CUBE_SQUISH = getSound("entity.magma_cube.squish")
    ENTITY_MAGMA_CUBE_SQUISH_SMALL = getSound("entity.magma_cube.squish_small")
    ENTITY_MINECART_INSIDE = getSound("entity.minecart.inside")
    ENTITY_MINECART_INSIDE_UNDERWATER = getSound("entity.minecart.inside.underwater")
    ENTITY_MINECART_RIDING = getSound("entity.minecart.riding")
    ENTITY_MOOSHROOM_CONVERT = getSound("entity.mooshroom.convert")
    ENTITY_MOOSHROOM_EAT = getSound("entity.mooshroom.eat")
    ENTITY_MOOSHROOM_MILK = getSound("entity.mooshroom.milk")
    ENTITY_MOOSHROOM_SHEAR = getSound("entity.mooshroom.shear")
    ENTITY_MOOSHROOM_SUSPICIOUS_MILK = getSound("entity.mooshroom.suspicious_milk")
    ENTITY_MULE_AMBIENT = getSound("entity.mule.ambient")
    ENTITY_MULE_ANGRY = getSound("entity.mule.angry")
    ENTITY_MULE_CHEST = getSound("entity.mule.chest")
    ENTITY_MULE_DEATH = getSound("entity.mule.death")
    ENTITY_MULE_EAT = getSound("entity.mule.eat")
    ENTITY_MULE_HURT = getSound("entity.mule.hurt")
    ENTITY_MULE_JUMP = getSound("entity.mule.jump")
    ENTITY_OCELOT_AMBIENT = getSound("entity.ocelot.ambient")
    ENTITY_OCELOT_DEATH = getSound("entity.ocelot.death")
    ENTITY_OCELOT_HURT = getSound("entity.ocelot.hurt")
    ENTITY_PAINTING_BREAK = getSound("entity.painting.break")
    ENTITY_PAINTING_PLACE = getSound("entity.painting.place")
    ENTITY_PANDA_AGGRESSIVE_AMBIENT = getSound("entity.panda.aggressive_ambient")
    ENTITY_PANDA_AMBIENT = getSound("entity.panda.ambient")
    ENTITY_PANDA_BITE = getSound("entity.panda.bite")
    ENTITY_PANDA_CANT_BREED = getSound("entity.panda.cant_breed")
    ENTITY_PANDA_DEATH = getSound("entity.panda.death")
    ENTITY_PANDA_EAT = getSound("entity.panda.eat")
    ENTITY_PANDA_HURT = getSound("entity.panda.hurt")
    ENTITY_PANDA_PRE_SNEEZE = getSound("entity.panda.pre_sneeze")
    ENTITY_PANDA_SNEEZE = getSound("entity.panda.sneeze")
    ENTITY_PANDA_STEP = getSound("entity.panda.step")
    ENTITY_PANDA_WORRIED_AMBIENT = getSound("entity.panda.worried_ambient")
    ENTITY_PARROT_AMBIENT = getSound("entity.parrot.ambient")
    ENTITY_PARROT_DEATH = getSound("entity.parrot.death")
    ENTITY_PARROT_EAT = getSound("entity.parrot.eat")
    ENTITY_PARROT_FLY = getSound("entity.parrot.fly")
    ENTITY_PARROT_HURT = getSound("entity.parrot.hurt")
    ENTITY_PARROT_IMITATE_BLAZE = getSound("entity.parrot.imitate.blaze")
    ENTITY_PARROT_IMITATE_BOGGED = getSound("entity.parrot.imitate.bogged")
    ENTITY_PARROT_IMITATE_BREEZE = getSound("entity.parrot.imitate.breeze")
    ENTITY_PARROT_IMITATE_CREAKING = getSound("entity.parrot.imitate.creaking")
    ENTITY_PARROT_IMITATE_CREEPER = getSound("entity.parrot.imitate.creeper")
    ENTITY_PARROT_IMITATE_DROWNED = getSound("entity.parrot.imitate.drowned")
    ENTITY_PARROT_IMITATE_ELDER_GUARDIAN = getSound("entity.parrot.imitate.elder_guardian")
    ENTITY_PARROT_IMITATE_ENDERMITE = getSound("entity.parrot.imitate.endermite")
    ENTITY_PARROT_IMITATE_ENDER_DRAGON = getSound("entity.parrot.imitate.ender_dragon")
    ENTITY_PARROT_IMITATE_EVOKER = getSound("entity.parrot.imitate.evoker")
    ENTITY_PARROT_IMITATE_GHAST = getSound("entity.parrot.imitate.ghast")
    ENTITY_PARROT_IMITATE_GUARDIAN = getSound("entity.parrot.imitate.guardian")
    ENTITY_PARROT_IMITATE_HOGLIN = getSound("entity.parrot.imitate.hoglin")
    ENTITY_PARROT_IMITATE_HUSK = getSound("entity.parrot.imitate.husk")
    ENTITY_PARROT_IMITATE_ILLUSIONER = getSound("entity.parrot.imitate.illusioner")
    ENTITY_PARROT_IMITATE_MAGMA_CUBE = getSound("entity.parrot.imitate.magma_cube")
    ENTITY_PARROT_IMITATE_PHANTOM = getSound("entity.parrot.imitate.phantom")
    ENTITY_PARROT_IMITATE_PIGLIN = getSound("entity.parrot.imitate.piglin")
    ENTITY_PARROT_IMITATE_PIGLIN_BRUTE = getSound("entity.parrot.imitate.piglin_brute")
    ENTITY_PARROT_IMITATE_PILLAGER = getSound("entity.parrot.imitate.pillager")
    ENTITY_PARROT_IMITATE_RAVAGER = getSound("entity.parrot.imitate.ravager")
    ENTITY_PARROT_IMITATE_SHULKER = getSound("entity.parrot.imitate.shulker")
    ENTITY_PARROT_IMITATE_SILVERFISH = getSound("entity.parrot.imitate.silverfish")
    ENTITY_PARROT_IMITATE_SKELETON = getSound("entity.parrot.imitate.skeleton")
    ENTITY_PARROT_IMITATE_SLIME = getSound("entity.parrot.imitate.slime")
    ENTITY_PARROT_IMITATE_SPIDER = getSound("entity.parrot.imitate.spider")
    ENTITY_PARROT_IMITATE_STRAY = getSound("entity.parrot.imitate.stray")
    ENTITY_PARROT_IMITATE_VEX = getSound("entity.parrot.imitate.vex")
    ENTITY_PARROT_IMITATE_VINDICATOR = getSound("entity.parrot.imitate.vindicator")
    ENTITY_PARROT_IMITATE_WARDEN = getSound("entity.parrot.imitate.warden")
    ENTITY_PARROT_IMITATE_WITCH = getSound("entity.parrot.imitate.witch")
    ENTITY_PARROT_IMITATE_WITHER = getSound("entity.parrot.imitate.wither")
    ENTITY_PARROT_IMITATE_WITHER_SKELETON = getSound("entity.parrot.imitate.wither_skeleton")
    ENTITY_PARROT_IMITATE_ZOGLIN = getSound("entity.parrot.imitate.zoglin")
    ENTITY_PARROT_IMITATE_ZOMBIE = getSound("entity.parrot.imitate.zombie")
    ENTITY_PARROT_IMITATE_ZOMBIE_VILLAGER = getSound("entity.parrot.imitate.zombie_villager")
    ENTITY_PARROT_STEP = getSound("entity.parrot.step")
    ENTITY_PHANTOM_AMBIENT = getSound("entity.phantom.ambient")
    ENTITY_PHANTOM_BITE = getSound("entity.phantom.bite")
    ENTITY_PHANTOM_DEATH = getSound("entity.phantom.death")
    ENTITY_PHANTOM_FLAP = getSound("entity.phantom.flap")
    ENTITY_PHANTOM_HURT = getSound("entity.phantom.hurt")
    ENTITY_PHANTOM_SWOOP = getSound("entity.phantom.swoop")
    ENTITY_PIGLIN_ADMIRING_ITEM = getSound("entity.piglin.admiring_item")
    ENTITY_PIGLIN_AMBIENT = getSound("entity.piglin.ambient")
    ENTITY_PIGLIN_ANGRY = getSound("entity.piglin.angry")
    ENTITY_PIGLIN_BRUTE_AMBIENT = getSound("entity.piglin_brute.ambient")
    ENTITY_PIGLIN_BRUTE_ANGRY = getSound("entity.piglin_brute.angry")
    ENTITY_PIGLIN_BRUTE_CONVERTED_TO_ZOMBIFIED = getSound("entity.piglin_brute.converted_to_zombified")
    ENTITY_PIGLIN_BRUTE_DEATH = getSound("entity.piglin_brute.death")
    ENTITY_PIGLIN_BRUTE_HURT = getSound("entity.piglin_brute.hurt")
    ENTITY_PIGLIN_BRUTE_STEP = getSound("entity.piglin_brute.step")
    ENTITY_PIGLIN_CELEBRATE = getSound("entity.piglin.celebrate")
    ENTITY_PIGLIN_CONVERTED_TO_ZOMBIFIED = getSound("entity.piglin.converted_to_zombified")
    ENTITY_PIGLIN_DEATH = getSound("entity.piglin.death")
    ENTITY_PIGLIN_HURT = getSound("entity.piglin.hurt")
    ENTITY_PIGLIN_JEALOUS = getSound("entity.piglin.jealous")
    ENTITY_PIGLIN_RETREAT = getSound("entity.piglin.retreat")
    ENTITY_PIGLIN_STEP = getSound("entity.piglin.step")
    ENTITY_PIG_AMBIENT = getSound("entity.pig.ambient")
    ENTITY_PIG_DEATH = getSound("entity.pig.death")
    ENTITY_PIG_HURT = getSound("entity.pig.hurt")
    ENTITY_PIG_SADDLE = getSound("entity.pig.saddle")
    ENTITY_PIG_STEP = getSound("entity.pig.step")
    ENTITY_PILLAGER_AMBIENT = getSound("entity.pillager.ambient")
    ENTITY_PILLAGER_CELEBRATE = getSound("entity.pillager.celebrate")
    ENTITY_PILLAGER_DEATH = getSound("entity.pillager.death")
    ENTITY_PILLAGER_HURT = getSound("entity.pillager.hurt")
    ENTITY_PLAYER_ATTACK_CRIT = getSound("entity.player.attack.crit")
    ENTITY_PLAYER_ATTACK_KNOCKBACK = getSound("entity.player.attack.knockback")
    ENTITY_PLAYER_ATTACK_NODAMAGE = getSound("entity.player.attack.nodamage")
    ENTITY_PLAYER_ATTACK_STRONG = getSound("entity.player.attack.strong")
    ENTITY_PLAYER_ATTACK_SWEEP = getSound("entity.player.attack.sweep")
    ENTITY_PLAYER_ATTACK_WEAK = getSound("entity.player.attack.weak")
    ENTITY_PLAYER_BIG_FALL = getSound("entity.player.big_fall")
    ENTITY_PLAYER_BREATH = getSound("entity.player.breath")
    ENTITY_PLAYER_BURP = getSound("entity.player.burp")
    ENTITY_PLAYER_DEATH = getSound("entity.player.death")
    ENTITY_PLAYER_HURT = getSound("entity.player.hurt")
    ENTITY_PLAYER_HURT_DROWN = getSound("entity.player.hurt_drown")
    ENTITY_PLAYER_HURT_FREEZE = getSound("entity.player.hurt_freeze")
    ENTITY_PLAYER_HURT_ON_FIRE = getSound("entity.player.hurt_on_fire")
    ENTITY_PLAYER_HURT_SWEET_BERRY_BUSH = getSound("entity.player.hurt_sweet_berry_bush")
    ENTITY_PLAYER_LEVELUP = getSound("entity.player.levelup")
    ENTITY_PLAYER_SMALL_FALL = getSound("entity.player.small_fall")
    ENTITY_PLAYER_SPLASH = getSound("entity.player.splash")
    ENTITY_PLAYER_SPLASH_HIGH_SPEED = getSound("entity.player.splash.high_speed")
    ENTITY_PLAYER_SWIM = getSound("entity.player.swim")
    ENTITY_PLAYER_TELEPORT = getSound("entity.player.teleport")
    ENTITY_POLAR_BEAR_AMBIENT = getSound("entity.polar_bear.ambient")
    ENTITY_POLAR_BEAR_AMBIENT_BABY = getSound("entity.polar_bear.ambient_baby")
    ENTITY_POLAR_BEAR_DEATH = getSound("entity.polar_bear.death")
    ENTITY_POLAR_BEAR_HURT = getSound("entity.polar_bear.hurt")
    ENTITY_POLAR_BEAR_STEP = getSound("entity.polar_bear.step")
    ENTITY_POLAR_BEAR_WARNING = getSound("entity.polar_bear.warning")
    ENTITY_PUFFER_FISH_AMBIENT = getSound("entity.puffer_fish.ambient")
    ENTITY_PUFFER_FISH_BLOW_OUT = getSound("entity.puffer_fish.blow_out")
    ENTITY_PUFFER_FISH_BLOW_UP = getSound("entity.puffer_fish.blow_up")
    ENTITY_PUFFER_FISH_DEATH = getSound("entity.puffer_fish.death")
    ENTITY_PUFFER_FISH_FLOP = getSound("entity.puffer_fish.flop")
    ENTITY_PUFFER_FISH_HURT = getSound("entity.puffer_fish.hurt")
    ENTITY_PUFFER_FISH_STING = getSound("entity.puffer_fish.sting")
    ENTITY_RABBIT_AMBIENT = getSound("entity.rabbit.ambient")
    ENTITY_RABBIT_ATTACK = getSound("entity.rabbit.attack")
    ENTITY_RABBIT_DEATH = getSound("entity.rabbit.death")
    ENTITY_RABBIT_HURT = getSound("entity.rabbit.hurt")
    ENTITY_RABBIT_JUMP = getSound("entity.rabbit.jump")
    ENTITY_RAVAGER_AMBIENT = getSound("entity.ravager.ambient")
    ENTITY_RAVAGER_ATTACK = getSound("entity.ravager.attack")
    ENTITY_RAVAGER_CELEBRATE = getSound("entity.ravager.celebrate")
    ENTITY_RAVAGER_DEATH = getSound("entity.ravager.death")
    ENTITY_RAVAGER_HURT = getSound("entity.ravager.hurt")
    ENTITY_RAVAGER_ROAR = getSound("entity.ravager.roar")
    ENTITY_RAVAGER_STEP = getSound("entity.ravager.step")
    ENTITY_RAVAGER_STUNNED = getSound("entity.ravager.stunned")
    ENTITY_SALMON_AMBIENT = getSound("entity.salmon.ambient")
    ENTITY_SALMON_DEATH = getSound("entity.salmon.death")
    ENTITY_SALMON_FLOP = getSound("entity.salmon.flop")
    ENTITY_SALMON_HURT = getSound("entity.salmon.hurt")
    ENTITY_SHEEP_AMBIENT = getSound("entity.sheep.ambient")
    ENTITY_SHEEP_DEATH = getSound("entity.sheep.death")
    ENTITY_SHEEP_HURT = getSound("entity.sheep.hurt")
    ENTITY_SHEEP_SHEAR = getSound("entity.sheep.shear")
    ENTITY_SHEEP_STEP = getSound("entity.sheep.step")
    ENTITY_SHULKER_AMBIENT = getSound("entity.shulker.ambient")
    ENTITY_SHULKER_BULLET_HIT = getSound("entity.shulker_bullet.hit")
    ENTITY_SHULKER_BULLET_HURT = getSound("entity.shulker_bullet.hurt")
    ENTITY_SHULKER_CLOSE = getSound("entity.shulker.close")
    ENTITY_SHULKER_DEATH = getSound("entity.shulker.death")
    ENTITY_SHULKER_HURT = getSound("entity.shulker.hurt")
    ENTITY_SHULKER_HURT_CLOSED = getSound("entity.shulker.hurt_closed")
    ENTITY_SHULKER_OPEN = getSound("entity.shulker.open")
    ENTITY_SHULKER_SHOOT = getSound("entity.shulker.shoot")
    ENTITY_SHULKER_TELEPORT = getSound("entity.shulker.teleport")
    ENTITY_SILVERFISH_AMBIENT = getSound("entity.silverfish.ambient")
    ENTITY_SILVERFISH_DEATH = getSound("entity.silverfish.death")
    ENTITY_SILVERFISH_HURT = getSound("entity.silverfish.hurt")
    ENTITY_SILVERFISH_STEP = getSound("entity.silverfish.step")
    ENTITY_SKELETON_AMBIENT = getSound("entity.skeleton.ambient")
    ENTITY_SKELETON_CONVERTED_TO_STRAY = getSound("entity.skeleton.converted_to_stray")
    ENTITY_SKELETON_DEATH = getSound("entity.skeleton.death")
    ENTITY_SKELETON_HORSE_AMBIENT = getSound("entity.skeleton_horse.ambient")
    ENTITY_SKELETON_HORSE_AMBIENT_WATER = getSound("entity.skeleton_horse.ambient_water")
    ENTITY_SKELETON_HORSE_DEATH = getSound("entity.skeleton_horse.death")
    ENTITY_SKELETON_HORSE_GALLOP_WATER = getSound("entity.skeleton_horse.gallop_water")
    ENTITY_SKELETON_HORSE_HURT = getSound("entity.skeleton_horse.hurt")
    ENTITY_SKELETON_HORSE_JUMP_WATER = getSound("entity.skeleton_horse.jump_water")
    ENTITY_SKELETON_HORSE_STEP_WATER = getSound("entity.skeleton_horse.step_water")
    ENTITY_SKELETON_HORSE_SWIM = getSound("entity.skeleton_horse.swim")
    ENTITY_SKELETON_HURT = getSound("entity.skeleton.hurt")
    ENTITY_SKELETON_SHOOT = getSound("entity.skeleton.shoot")
    ENTITY_SKELETON_STEP = getSound("entity.skeleton.step")
    ENTITY_SLIME_ATTACK = getSound("entity.slime.attack")
    ENTITY_SLIME_DEATH = getSound("entity.slime.death")
    ENTITY_SLIME_DEATH_SMALL = getSound("entity.slime.death_small")
    ENTITY_SLIME_HURT = getSound("entity.slime.hurt")
    ENTITY_SLIME_HURT_SMALL = getSound("entity.slime.hurt_small")
    ENTITY_SLIME_JUMP = getSound("entity.slime.jump")
    ENTITY_SLIME_JUMP_SMALL = getSound("entity.slime.jump_small")
    ENTITY_SLIME_SQUISH = getSound("entity.slime.squish")
    ENTITY_SLIME_SQUISH_SMALL = getSound("entity.slime.squish_small")
    ENTITY_SNIFFER_DEATH = getSound("entity.sniffer.death")
    ENTITY_SNIFFER_DIGGING = getSound("entity.sniffer.digging")
    ENTITY_SNIFFER_DIGGING_STOP = getSound("entity.sniffer.digging_stop")
    ENTITY_SNIFFER_DROP_SEED = getSound("entity.sniffer.drop_seed")
    ENTITY_SNIFFER_EAT = getSound("entity.sniffer.eat")
    ENTITY_SNIFFER_HAPPY = getSound("entity.sniffer.happy")
    ENTITY_SNIFFER_HURT = getSound("entity.sniffer.hurt")
    ENTITY_SNIFFER_IDLE = getSound("entity.sniffer.idle")
    ENTITY_SNIFFER_SCENTING = getSound("entity.sniffer.scenting")
    ENTITY_SNIFFER_SEARCHING = getSound("entity.sniffer.searching")
    ENTITY_SNIFFER_SNIFFING = getSound("entity.sniffer.sniffing")
    ENTITY_SNIFFER_STEP = getSound("entity.sniffer.step")
    ENTITY_SNOWBALL_THROW = getSound("entity.snowball.throw")
    ENTITY_SNOW_GOLEM_AMBIENT = getSound("entity.snow_golem.ambient")
    ENTITY_SNOW_GOLEM_DEATH = getSound("entity.snow_golem.death")
    ENTITY_SNOW_GOLEM_HURT = getSound("entity.snow_golem.hurt")
    ENTITY_SNOW_GOLEM_SHEAR = getSound("entity.snow_golem.shear")
    ENTITY_SNOW_GOLEM_SHOOT = getSound("entity.snow_golem.shoot")
    ENTITY_SPIDER_AMBIENT = getSound("entity.spider.ambient")
    ENTITY_SPIDER_DEATH = getSound("entity.spider.death")
    ENTITY_SPIDER_HURT = getSound("entity.spider.hurt")
    ENTITY_SPIDER_STEP = getSound("entity.spider.step")
    ENTITY_SPLASH_POTION_BREAK = getSound("entity.splash_potion.break")
    ENTITY_SPLASH_POTION_THROW = getSound("entity.splash_potion.throw")
    ENTITY_SQUID_AMBIENT = getSound("entity.squid.ambient")
    ENTITY_SQUID_DEATH = getSound("entity.squid.death")
    ENTITY_SQUID_HURT = getSound("entity.squid.hurt")
    ENTITY_SQUID_SQUIRT = getSound("entity.squid.squirt")
    ENTITY_STRAY_AMBIENT = getSound("entity.stray.ambient")
    ENTITY_STRAY_DEATH = getSound("entity.stray.death")
    ENTITY_STRAY_HURT = getSound("entity.stray.hurt")
    ENTITY_STRAY_STEP = getSound("entity.stray.step")
    ENTITY_STRIDER_AMBIENT = getSound("entity.strider.ambient")
    ENTITY_STRIDER_DEATH = getSound("entity.strider.death")
    ENTITY_STRIDER_EAT = getSound("entity.strider.eat")
    ENTITY_STRIDER_HAPPY = getSound("entity.strider.happy")
    ENTITY_STRIDER_HURT = getSound("entity.strider.hurt")
    ENTITY_STRIDER_RETREAT = getSound("entity.strider.retreat")
    ENTITY_STRIDER_SADDLE = getSound("entity.strider.saddle")
    ENTITY_STRIDER_STEP = getSound("entity.strider.step")
    ENTITY_STRIDER_STEP_LAVA = getSound("entity.strider.step_lava")
    ENTITY_TADPOLE_DEATH = getSound("entity.tadpole.death")
    ENTITY_TADPOLE_FLOP = getSound("entity.tadpole.flop")
    ENTITY_TADPOLE_GROW_UP = getSound("entity.tadpole.grow_up")
    ENTITY_TADPOLE_HURT = getSound("entity.tadpole.hurt")
    ENTITY_TNT_PRIMED = getSound("entity.tnt.primed")
    ENTITY_TROPICAL_FISH_AMBIENT = getSound("entity.tropical_fish.ambient")
    ENTITY_TROPICAL_FISH_DEATH = getSound("entity.tropical_fish.death")
    ENTITY_TROPICAL_FISH_FLOP = getSound("entity.tropical_fish.flop")
    ENTITY_TROPICAL_FISH_HURT = getSound("entity.tropical_fish.hurt")
    ENTITY_TURTLE_AMBIENT_LAND = getSound("entity.turtle.ambient_land")
    ENTITY_TURTLE_DEATH = getSound("entity.turtle.death")
    ENTITY_TURTLE_DEATH_BABY = getSound("entity.turtle.death_baby")
    ENTITY_TURTLE_EGG_BREAK = getSound("entity.turtle.egg_break")
    ENTITY_TURTLE_EGG_CRACK = getSound("entity.turtle.egg_crack")
    ENTITY_TURTLE_EGG_HATCH = getSound("entity.turtle.egg_hatch")
    ENTITY_TURTLE_HURT = getSound("entity.turtle.hurt")
    ENTITY_TURTLE_HURT_BABY = getSound("entity.turtle.hurt_baby")
    ENTITY_TURTLE_LAY_EGG = getSound("entity.turtle.lay_egg")
    ENTITY_TURTLE_SHAMBLE = getSound("entity.turtle.shamble")
    ENTITY_TURTLE_SHAMBLE_BABY = getSound("entity.turtle.shamble_baby")
    ENTITY_TURTLE_SWIM = getSound("entity.turtle.swim")
    ENTITY_VEX_AMBIENT = getSound("entity.vex.ambient")
    ENTITY_VEX_CHARGE = getSound("entity.vex.charge")
    ENTITY_VEX_DEATH = getSound("entity.vex.death")
    ENTITY_VEX_HURT = getSound("entity.vex.hurt")
    ENTITY_VILLAGER_AMBIENT = getSound("entity.villager.ambient")
    ENTITY_VILLAGER_CELEBRATE = getSound("entity.villager.celebrate")
    ENTITY_VILLAGER_DEATH = getSound("entity.villager.death")
    ENTITY_VILLAGER_HURT = getSound("entity.villager.hurt")
    ENTITY_VILLAGER_NO = getSound("entity.villager.no")
    ENTITY_VILLAGER_TRADE = getSound("entity.villager.trade")
    ENTITY_VILLAGER_WORK_ARMORER = getSound("entity.villager.work_armorer")
    ENTITY_VILLAGER_WORK_BUTCHER = getSound("entity.villager.work_butcher")
    ENTITY_VILLAGER_WORK_CARTOGRAPHER = getSound("entity.villager.work_cartographer")
    ENTITY_VILLAGER_WORK_CLERIC = getSound("entity.villager.work_cleric")
    ENTITY_VILLAGER_WORK_FARMER = getSound("entity.villager.work_farmer")
    ENTITY_VILLAGER_WORK_FISHERMAN = getSound("entity.villager.work_fisherman")
    ENTITY_VILLAGER_WORK_FLETCHER = getSound("entity.villager.work_fletcher")
    ENTITY_VILLAGER_WORK_LEATHERWORKER = getSound("entity.villager.work_leatherworker")
    ENTITY_VILLAGER_WORK_LIBRARIAN = getSound("entity.villager.work_librarian")
    ENTITY_VILLAGER_WORK_MASON = getSound("entity.villager.work_mason")
    ENTITY_VILLAGER_WORK_SHEPHERD = getSound("entity.villager.work_shepherd")
    ENTITY_VILLAGER_WORK_TOOLSMITH = getSound("entity.villager.work_toolsmith")
    ENTITY_VILLAGER_WORK_WEAPONSMITH = getSound("entity.villager.work_weaponsmith")
    ENTITY_VILLAGER_YES = getSound("entity.villager.yes")
    ENTITY_VINDICATOR_AMBIENT = getSound("entity.vindicator.ambient")
    ENTITY_VINDICATOR_CELEBRATE = getSound("entity.vindicator.celebrate")
    ENTITY_VINDICATOR_DEATH = getSound("entity.vindicator.death")
    ENTITY_VINDICATOR_HURT = getSound("entity.vindicator.hurt")
    ENTITY_WANDERING_TRADER_AMBIENT = getSound("entity.wandering_trader.ambient")
    ENTITY_WANDERING_TRADER_DEATH = getSound("entity.wandering_trader.death")
    ENTITY_WANDERING_TRADER_DISAPPEARED = getSound("entity.wandering_trader.disappeared")
    ENTITY_WANDERING_TRADER_DRINK_MILK = getSound("entity.wandering_trader.drink_milk")
    ENTITY_WANDERING_TRADER_DRINK_POTION = getSound("entity.wandering_trader.drink_potion")
    ENTITY_WANDERING_TRADER_HURT = getSound("entity.wandering_trader.hurt")
    ENTITY_WANDERING_TRADER_NO = getSound("entity.wandering_trader.no")
    ENTITY_WANDERING_TRADER_REAPPEARED = getSound("entity.wandering_trader.reappeared")
    ENTITY_WANDERING_TRADER_TRADE = getSound("entity.wandering_trader.trade")
    ENTITY_WANDERING_TRADER_YES = getSound("entity.wandering_trader.yes")
    ENTITY_WARDEN_AGITATED = getSound("entity.warden.agitated")
    ENTITY_WARDEN_AMBIENT = getSound("entity.warden.ambient")
    ENTITY_WARDEN_ANGRY = getSound("entity.warden.angry")
    ENTITY_WARDEN_ATTACK_IMPACT = getSound("entity.warden.attack_impact")
    ENTITY_WARDEN_DEATH = getSound("entity.warden.death")
    ENTITY_WARDEN_DIG = getSound("entity.warden.dig")
    ENTITY_WARDEN_EMERGE = getSound("entity.warden.emerge")
    ENTITY_WARDEN_HEARTBEAT = getSound("entity.warden.heartbeat")
    ENTITY_WARDEN_HURT = getSound("entity.warden.hurt")
    ENTITY_WARDEN_LISTENING = getSound("entity.warden.listening")
    ENTITY_WARDEN_LISTENING_ANGRY = getSound("entity.warden.listening_angry")
    ENTITY_WARDEN_NEARBY_CLOSE = getSound("entity.warden.nearby_close")
    ENTITY_WARDEN_NEARBY_CLOSER = getSound("entity.warden.nearby_closer")
    ENTITY_WARDEN_NEARBY_CLOSEST = getSound("entity.warden.nearby_closest")
    ENTITY_WARDEN_ROAR = getSound("entity.warden.roar")
    ENTITY_WARDEN_SNIFF = getSound("entity.warden.sniff")
    ENTITY_WARDEN_SONIC_BOOM = getSound("entity.warden.sonic_boom")
    ENTITY_WARDEN_SONIC_CHARGE = getSound("entity.warden.sonic_charge")
    ENTITY_WARDEN_STEP = getSound("entity.warden.step")
    ENTITY_WARDEN_TENDRIL_CLICKS = getSound("entity.warden.tendril_clicks")
    ENTITY_WIND_CHARGE_THROW = getSound("entity.wind_charge.throw")
    ENTITY_WIND_CHARGE_WIND_BURST = getSound("entity.wind_charge.wind_burst")
    ENTITY_WITCH_AMBIENT = getSound("entity.witch.ambient")
    ENTITY_WITCH_CELEBRATE = getSound("entity.witch.celebrate")
    ENTITY_WITCH_DEATH = getSound("entity.witch.death")
    ENTITY_WITCH_DRINK = getSound("entity.witch.drink")
    ENTITY_WITCH_HURT = getSound("entity.witch.hurt")
    ENTITY_WITCH_THROW = getSound("entity.witch.throw")
    ENTITY_WITHER_AMBIENT = getSound("entity.wither.ambient")
    ENTITY_WITHER_BREAK_BLOCK = getSound("entity.wither.break_block")
    ENTITY_WITHER_DEATH = getSound("entity.wither.death")
    ENTITY_WITHER_HURT = getSound("entity.wither.hurt")
    ENTITY_WITHER_SHOOT = getSound("entity.wither.shoot")
    ENTITY_WITHER_SKELETON_AMBIENT = getSound("entity.wither_skeleton.ambient")
    ENTITY_WITHER_SKELETON_DEATH = getSound("entity.wither_skeleton.death")
    ENTITY_WITHER_SKELETON_HURT = getSound("entity.wither_skeleton.hurt")
    ENTITY_WITHER_SKELETON_STEP = getSound("entity.wither_skeleton.step")
    ENTITY_WITHER_SPAWN = getSound("entity.wither.spawn")
    ENTITY_WOLF_AMBIENT = getSound("entity.wolf.ambient")
    ENTITY_WOLF_DEATH = getSound("entity.wolf.death")
    ENTITY_WOLF_GROWL = getSound("entity.wolf.growl")
    ENTITY_WOLF_HOWL = getSound("entity.wolf.howl")
    ENTITY_WOLF_HURT = getSound("entity.wolf.hurt")
    ENTITY_WOLF_PANT = getSound("entity.wolf.pant")
    ENTITY_WOLF_SHAKE = getSound("entity.wolf.shake")
    ENTITY_WOLF_STEP = getSound("entity.wolf.step")
    ENTITY_WOLF_WHINE = getSound("entity.wolf.whine")
    ENTITY_ZOGLIN_AMBIENT = getSound("entity.zoglin.ambient")
    ENTITY_ZOGLIN_ANGRY = getSound("entity.zoglin.angry")
    ENTITY_ZOGLIN_ATTACK = getSound("entity.zoglin.attack")
    ENTITY_ZOGLIN_DEATH = getSound("entity.zoglin.death")
    ENTITY_ZOGLIN_HURT = getSound("entity.zoglin.hurt")
    ENTITY_ZOGLIN_STEP = getSound("entity.zoglin.step")
    ENTITY_ZOMBIE_AMBIENT = getSound("entity.zombie.ambient")
    ENTITY_ZOMBIE_ATTACK_IRON_DOOR = getSound("entity.zombie.attack_iron_door")
    ENTITY_ZOMBIE_ATTACK_WOODEN_DOOR = getSound("entity.zombie.attack_wooden_door")
    ENTITY_ZOMBIE_BREAK_WOODEN_DOOR = getSound("entity.zombie.break_wooden_door")
    ENTITY_ZOMBIE_CONVERTED_TO_DROWNED = getSound("entity.zombie.converted_to_drowned")
    ENTITY_ZOMBIE_DEATH = getSound("entity.zombie.death")
    ENTITY_ZOMBIE_DESTROY_EGG = getSound("entity.zombie.destroy_egg")
    ENTITY_ZOMBIE_HORSE_AMBIENT = getSound("entity.zombie_horse.ambient")
    ENTITY_ZOMBIE_HORSE_DEATH = getSound("entity.zombie_horse.death")
    ENTITY_ZOMBIE_HORSE_HURT = getSound("entity.zombie_horse.hurt")
    ENTITY_ZOMBIE_HURT = getSound("entity.zombie.hurt")
    ENTITY_ZOMBIE_INFECT = getSound("entity.zombie.infect")
    ENTITY_ZOMBIE_STEP = getSound("entity.zombie.step")
    ENTITY_ZOMBIE_VILLAGER_AMBIENT = getSound("entity.zombie_villager.ambient")
    ENTITY_ZOMBIE_VILLAGER_CONVERTED = getSound("entity.zombie_villager.converted")
    ENTITY_ZOMBIE_VILLAGER_CURE = getSound("entity.zombie_villager.cure")
    ENTITY_ZOMBIE_VILLAGER_DEATH = getSound("entity.zombie_villager.death")
    ENTITY_ZOMBIE_VILLAGER_HURT = getSound("entity.zombie_villager.hurt")
    ENTITY_ZOMBIE_VILLAGER_STEP = getSound("entity.zombie_villager.step")
    ENTITY_ZOMBIFIED_PIGLIN_AMBIENT = getSound("entity.zombified_piglin.ambient")
    ENTITY_ZOMBIFIED_PIGLIN_ANGRY = getSound("entity.zombified_piglin.angry")
    ENTITY_ZOMBIFIED_PIGLIN_DEATH = getSound("entity.zombified_piglin.death")
    ENTITY_ZOMBIFIED_PIGLIN_HURT = getSound("entity.zombified_piglin.hurt")
    EVENT_MOB_EFFECT_BAD_OMEN = getSound("event.mob_effect.bad_omen")
    EVENT_MOB_EFFECT_RAID_OMEN = getSound("event.mob_effect.raid_omen")
    EVENT_MOB_EFFECT_TRIAL_OMEN = getSound("event.mob_effect.trial_omen")
    EVENT_RAID_HORN = getSound("event.raid.horn")
    INTENTIONALLY_EMPTY = getSound("intentionally_empty")
    ITEM_ARMOR_EQUIP_CHAIN = getSound("item.armor.equip_chain")
    ITEM_ARMOR_EQUIP_DIAMOND = getSound("item.armor.equip_diamond")
    ITEM_ARMOR_EQUIP_ELYTRA = getSound("item.armor.equip_elytra")
    ITEM_ARMOR_EQUIP_GENERIC = getSound("item.armor.equip_generic")
    ITEM_ARMOR_EQUIP_GOLD = getSound("item.armor.equip_gold")
    ITEM_ARMOR_EQUIP_IRON = getSound("item.armor.equip_iron")
    ITEM_ARMOR_EQUIP_LEATHER = getSound("item.armor.equip_leather")
    ITEM_ARMOR_EQUIP_NETHERITE = getSound("item.armor.equip_netherite")
    ITEM_ARMOR_EQUIP_TURTLE = getSound("item.armor.equip_turtle")
    ITEM_ARMOR_EQUIP_WOLF = getSound("item.armor.equip_wolf")
    ITEM_ARMOR_UNEQUIP_WOLF = getSound("item.armor.unequip_wolf")
    ITEM_AXE_SCRAPE = getSound("item.axe.scrape")
    ITEM_AXE_STRIP = getSound("item.axe.strip")
    ITEM_AXE_WAX_OFF = getSound("item.axe.wax_off")
    ITEM_BONE_MEAL_USE = getSound("item.bone_meal.use")
    ITEM_BOOK_PAGE_TURN = getSound("item.book.page_turn")
    ITEM_BOOK_PUT = getSound("item.book.put")
    ITEM_BOTTLE_EMPTY = getSound("item.bottle.empty")
    ITEM_BOTTLE_FILL = getSound("item.bottle.fill")
    ITEM_BOTTLE_FILL_DRAGONBREATH = getSound("item.bottle.fill_dragonbreath")
    ITEM_BRUSH_BRUSHING_GENERIC = getSound("item.brush.brushing.generic")
    ITEM_BRUSH_BRUSHING_GRAVEL = getSound("item.brush.brushing.gravel")
    ITEM_BRUSH_BRUSHING_GRAVEL_COMPLETE = getSound("item.brush.brushing.gravel.complete")
    ITEM_BRUSH_BRUSHING_SAND = getSound("item.brush.brushing.sand")
    ITEM_BRUSH_BRUSHING_SAND_COMPLETE = getSound("item.brush.brushing.sand.complete")
    ITEM_BUCKET_EMPTY = getSound("item.bucket.empty")
    ITEM_BUCKET_EMPTY_AXOLOTL = getSound("item.bucket.empty_axolotl")
    ITEM_BUCKET_EMPTY_FISH = getSound("item.bucket.empty_fish")
    ITEM_BUCKET_EMPTY_LAVA = getSound("item.bucket.empty_lava")
    ITEM_BUCKET_EMPTY_POWDER_SNOW = getSound("item.bucket.empty_powder_snow")
    ITEM_BUCKET_EMPTY_TADPOLE = getSound("item.bucket.empty_tadpole")
    ITEM_BUCKET_FILL = getSound("item.bucket.fill")
    ITEM_BUCKET_FILL_AXOLOTL = getSound("item.bucket.fill_axolotl")
    ITEM_BUCKET_FILL_FISH = getSound("item.bucket.fill_fish")
    ITEM_BUCKET_FILL_LAVA = getSound("item.bucket.fill_lava")
    ITEM_BUCKET_FILL_POWDER_SNOW = getSound("item.bucket.fill_powder_snow")
    ITEM_BUCKET_FILL_TADPOLE = getSound("item.bucket.fill_tadpole")
    ITEM_BUNDLE_DROP_CONTENTS = getSound("item.bundle.drop_contents")
    ITEM_BUNDLE_INSERT = getSound("item.bundle.insert")
    ITEM_BUNDLE_INSERT_FAIL = getSound("item.bundle.insert_fail")
    ITEM_BUNDLE_REMOVE_ONE = getSound("item.bundle.remove_one")
    ITEM_CHORUS_FRUIT_TELEPORT = getSound("item.chorus_fruit.teleport")
    ITEM_CROP_PLANT = getSound("item.crop.plant")
    ITEM_CROSSBOW_HIT = getSound("item.crossbow.hit")
    ITEM_CROSSBOW_LOADING_END = getSound("item.crossbow.loading_end")
    ITEM_CROSSBOW_LOADING_MIDDLE = getSound("item.crossbow.loading_middle")
    ITEM_CROSSBOW_LOADING_START = getSound("item.crossbow.loading_start")
    ITEM_CROSSBOW_QUICK_CHARGE_1 = getSound("item.crossbow.quick_charge_1")
    ITEM_CROSSBOW_QUICK_CHARGE_2 = getSound("item.crossbow.quick_charge_2")
    ITEM_CROSSBOW_QUICK_CHARGE_3 = getSound("item.crossbow.quick_charge_3")
    ITEM_CROSSBOW_SHOOT = getSound("item.crossbow.shoot")
    ITEM_DYE_USE = getSound("item.dye.use")
    ITEM_ELYTRA_FLYING = getSound("item.elytra.flying")
    ITEM_FIRECHARGE_USE = getSound("item.firecharge.use")
    ITEM_FLINTANDSTEEL_USE = getSound("item.flintandsteel.use")
    ITEM_GLOW_INK_SAC_USE = getSound("item.glow_ink_sac.use")
    ITEM_GOAT_HORN_SOUND_0 = getSound("item.goat_horn.sound.0")
    ITEM_GOAT_HORN_SOUND_1 = getSound("item.goat_horn.sound.1")
    ITEM_GOAT_HORN_SOUND_2 = getSound("item.goat_horn.sound.2")
    ITEM_GOAT_HORN_SOUND_3 = getSound("item.goat_horn.sound.3")
    ITEM_GOAT_HORN_SOUND_4 = getSound("item.goat_horn.sound.4")
    ITEM_GOAT_HORN_SOUND_5 = getSound("item.goat_horn.sound.5")
    ITEM_GOAT_HORN_SOUND_6 = getSound("item.goat_horn.sound.6")
    ITEM_GOAT_HORN_SOUND_7 = getSound("item.goat_horn.sound.7")
    ITEM_HOE_TILL = getSound("item.hoe.till")
    ITEM_HONEYCOMB_WAX_ON = getSound("item.honeycomb.wax_on")
    ITEM_HONEY_BOTTLE_DRINK = getSound("item.honey_bottle.drink")
    ITEM_INK_SAC_USE = getSound("item.ink_sac.use")
    ITEM_LODESTONE_COMPASS_LOCK = getSound("item.lodestone_compass.lock")
    ITEM_MACE_SMASH_AIR = getSound("item.mace.smash_air")
    ITEM_MACE_SMASH_GROUND = getSound("item.mace.smash_ground")
    ITEM_MACE_SMASH_GROUND_HEAVY = getSound("item.mace.smash_ground_heavy")
    ITEM_NETHER_WART_PLANT = getSound("item.nether_wart.plant")
    ITEM_OMINOUS_BOTTLE_DISPOSE = getSound("item.ominous_bottle.dispose")
    ITEM_SHIELD_BLOCK = getSound("item.shield.block")
    ITEM_SHIELD_BREAK = getSound("item.shield.break")
    ITEM_SHOVEL_FLATTEN = getSound("item.shovel.flatten")
    ITEM_SPYGLASS_STOP_USING = getSound("item.spyglass.stop_using")
    ITEM_SPYGLASS_USE = getSound("item.spyglass.use")
    ITEM_TOTEM_USE = getSound("item.totem.use")
    ITEM_TRIDENT_HIT = getSound("item.trident.hit")
    ITEM_TRIDENT_HIT_GROUND = getSound("item.trident.hit_ground")
    ITEM_TRIDENT_RETURN = getSound("item.trident.return")
    ITEM_TRIDENT_RIPTIDE_1 = getSound("item.trident.riptide_1")
    ITEM_TRIDENT_RIPTIDE_2 = getSound("item.trident.riptide_2")
    ITEM_TRIDENT_RIPTIDE_3 = getSound("item.trident.riptide_3")
    ITEM_TRIDENT_THROW = getSound("item.trident.throw")
    ITEM_TRIDENT_THUNDER = getSound("item.trident.thunder")
    ITEM_WOLF_ARMOR_BREAK = getSound("item.wolf_armor.break")
    ITEM_WOLF_ARMOR_CRACK = getSound("item.wolf_armor.crack")
    ITEM_WOLF_ARMOR_DAMAGE = getSound("item.wolf_armor.damage")
    ITEM_WOLF_ARMOR_REPAIR = getSound("item.wolf_armor.repair")
    MUSIC_CREATIVE = getSound("music.creative")
    MUSIC_CREDITS = getSound("music.credits")
    MUSIC_DISC_11 = getSound("music_disc.11")
    MUSIC_DISC_13 = getSound("music_disc.13")
    MUSIC_DISC_5 = getSound("music_disc.5")
    MUSIC_DISC_BLOCKS = getSound("music_disc.blocks")
    MUSIC_DISC_CAT = getSound("music_disc.cat")
    MUSIC_DISC_CHIRP = getSound("music_disc.chirp")
    MUSIC_DISC_CREATOR = getSound("music_disc.creator")
    MUSIC_DISC_CREATOR_MUSIC_BOX = getSound("music_disc.creator_music_box")
    MUSIC_DISC_FAR = getSound("music_disc.far")
    MUSIC_DISC_MALL = getSound("music_disc.mall")
    MUSIC_DISC_MELLOHI = getSound("music_disc.mellohi")
    MUSIC_DISC_OTHERSIDE = getSound("music_disc.otherside")
    MUSIC_DISC_PIGSTEP = getSound("music_disc.pigstep")
    MUSIC_DISC_PRECIPICE = getSound("music_disc.precipice")
    MUSIC_DISC_RELIC = getSound("music_disc.relic")
    MUSIC_DISC_STAL = getSound("music_disc.stal")
    MUSIC_DISC_STRAD = getSound("music_disc.strad")
    MUSIC_DISC_WAIT = getSound("music_disc.wait")
    MUSIC_DISC_WARD = getSound("music_disc.ward")
    MUSIC_DRAGON = getSound("music.dragon")
    MUSIC_END = getSound("music.end")
    MUSIC_GAME = getSound("music.game")
    MUSIC_MENU = getSound("music.menu")
    MUSIC_NETHER_BASALT_DELTAS = getSound("music.nether.basalt_deltas")
    MUSIC_NETHER_CRIMSON_FOREST = getSound("music.nether.crimson_forest")
    MUSIC_NETHER_NETHER_WASTES = getSound("music.nether.nether_wastes")
    MUSIC_NETHER_SOUL_SAND_VALLEY = getSound("music.nether.soul_sand_valley")
    MUSIC_NETHER_WARPED_FOREST = getSound("music.nether.warped_forest")
    MUSIC_OVERWORLD_BADLANDS = getSound("music.overworld.badlands")
    MUSIC_OVERWORLD_BAMBOO_JUNGLE = getSound("music.overworld.bamboo_jungle")
    MUSIC_OVERWORLD_CHERRY_GROVE = getSound("music.overworld.cherry_grove")
    MUSIC_OVERWORLD_DEEP_DARK = getSound("music.overworld.deep_dark")
    MUSIC_OVERWORLD_DESERT = getSound("music.overworld.desert")
    MUSIC_OVERWORLD_DRIPSTONE_CAVES = getSound("music.overworld.dripstone_caves")
    MUSIC_OVERWORLD_FLOWER_FOREST = getSound("music.overworld.flower_forest")
    MUSIC_OVERWORLD_FOREST = getSound("music.overworld.forest")
    MUSIC_OVERWORLD_FROZEN_PEAKS = getSound("music.overworld.frozen_peaks")
    MUSIC_OVERWORLD_GROVE = getSound("music.overworld.grove")
    MUSIC_OVERWORLD_JAGGED_PEAKS = getSound("music.overworld.jagged_peaks")
    MUSIC_OVERWORLD_JUNGLE = getSound("music.overworld.jungle")
    MUSIC_OVERWORLD_LUSH_CAVES = getSound("music.overworld.lush_caves")
    MUSIC_OVERWORLD_MEADOW = getSound("music.overworld.meadow")
    MUSIC_OVERWORLD_OLD_GROWTH_TAIGA = getSound("music.overworld.old_growth_taiga")
    MUSIC_OVERWORLD_SNOWY_SLOPES = getSound("music.overworld.snowy_slopes")
    MUSIC_OVERWORLD_SPARSE_JUNGLE = getSound("music.overworld.sparse_jungle")
    MUSIC_OVERWORLD_STONY_PEAKS = getSound("music.overworld.stony_peaks")
    MUSIC_OVERWORLD_SWAMP = getSound("music.overworld.swamp")
    MUSIC_UNDER_WATER = getSound("music.under_water")
    PARTICLE_SOUL_ESCAPE = getSound("particle.soul_escape")
    UI_BUTTON_CLICK = getSound("ui.button.click")
    UI_CARTOGRAPHY_TABLE_TAKE_RESULT = getSound("ui.cartography_table.take_result")
    UI_HUD_BUBBLE_POP = getSound("ui.hud.bubble_pop")
    UI_LOOM_SELECT_PATTERN = getSound("ui.loom.select_pattern")
    UI_LOOM_TAKE_RESULT = getSound("ui.loom.take_result")
    UI_STONECUTTER_SELECT_RECIPE = getSound("ui.stonecutter.select_recipe")
    UI_STONECUTTER_TAKE_RESULT = getSound("ui.stonecutter.take_result")
    UI_TOAST_CHALLENGE_COMPLETE = getSound("ui.toast.challenge_complete")
    UI_TOAST_IN = getSound("ui.toast.in")
    UI_TOAST_OUT = getSound("ui.toast.out")
    WEATHER_RAIN = getSound("weather.rain")
    WEATHER_RAIN_ABOVE = getSound("weather.rain.above")


    @staticmethod
    def getSound(key: str) -> "Sound":
        ...


    def getKey(self) -> "NamespacedKey":
        """
        See
        - .isRegistered()

        Deprecated
        - A key might not always be present, use .getKeyOrThrow() instead.
        """
        ...


    @staticmethod
    def valueOf(name: str) -> "Sound":
        """
        Arguments
        - name: of the sound.

        Returns
        - the sound with the given name.

        Deprecated
        - only for backwards compatibility, use Registry.get(NamespacedKey) instead.
        """
        ...


    @staticmethod
    def values() -> list["Sound"]:
        """
        Returns
        - an array of all known sounds.

        Deprecated
        - use Registry.iterator().
        """
        ...
